@@ -1,7 +1,7 @@
 #
 #  gpsman --- GPS Manager: a manager for GPS receiver data
 #
-#  Copyright (c) 2001 Miguel Filgueiras (mig@ncc.up.pt) / Universidade do Porto
+#  Copyright (c) 2003 Miguel Filgueiras (mig@ncc.up.pt) / Universidade do Porto
 #
 #    This program is free software; you can redistribute it and/or modify
 #      it under the terms of the GNU General Public License as published by
@@ -17,9 +17,12 @@
 #      along with this program.
 #
 #  File: garmin_nmea.tcl
-#  Last change:  3 June 2001
+#  Last change:  22 October 2003
 #
 
+## procedures used to interpret NMEA-0183 sentences from a receiver or
+##  a file (see files_foreign.tcl)
+
 ### Some NMEA-0183 sentences (check proc CollectNMEAData for the information
 #    actually used)
 # GPRMC Recommended minimum specific GPS/Transit data
@@ -48,7 +51,7 @@ array set NMEASent {
     GPGGA,tp {time DMM,N/S DMM,E/W status=0/1/2 int float float,=M
               float,=M float int}
     GPGLL  {lat long time sel}
-    GPGLL,tp {DMM,N/S DMM,E/W status=?/A}
+    GPGLL,tp {DMM,N/S DMM,E/W time status=?/A}
     GPBOD  {bearStartDest magnbearStartDest WPDest WPStart}
     GPBOD,tp {float,=T float,=M string string}
     GPBWC  {time WPlat WPlong bearWP magnbearWP nm-WPdist WPname}
@@ -79,29 +82,42 @@ array set NMEAStatus {
     alt=3  GPS
 }
 
-set NMEAPVT 0
+set NMEARLTM 0
 
 ### user control
 
-proc GarminStartNMEA {} {
-    # start real time logging with NMEA 0183 protocol
+proc GarminStartNMEA {from args} {
+    # start interpretation of NMEA 0183 sentences
+    #  $from in {rec, file} for, respectively,
+    #    real time logging from receiver
+    #    reading from a file $args
     # return 0 on failure
-    global NMEAPVT NMEAData NMEACurrentTime NMEACurrentDate NMEASeen
+    global NMEARLTM NMEAData NMEACurrentTime NMEACurrentDate NMEASeen \
+	    NMEAFrom NMEADataFile NMEADefDate NMEAPrevSecs
 
-    if { ! $NMEAPVT } {
-	set NMEAData  "_ _ _ _ _ _ _ _ _"
+    if { ! $NMEARLTM } {
+	set NMEAData  "_ _ _ _ _ _ _ _ _ _"
 	set NMEASeen "" ; set NMEACurrentTime undef
-	set NMEACurrentDate [clock format [clock seconds] -format "-%Y %m %d"]
-	return [set NMEAPVT [StartLineProtocol ProcNMEALine 4800]]
+	set NMEACurrentDate ""
+	if { [set NMEAFrom $from] == "rec" } {
+	    set NMEADefDate [clock format [clock seconds] -format "%Y %m %d"]
+	    set NMEAPrevSecs -2
+	    return [set NMEARLTM [StartLineProtocol ProcNMEALine 4800]]
+	}
+	set NMEADefDate "1990 1 1" ; set NMEAPrevSecs -1
+	set NMEADataFile $args
+	set NMEARLTM 1
+    } elseif { $NMEAFrom != $from || $from == "file" } {
+	return 0
     }
     return 1
 }
 
 proc GarminStopNMEA {} {
-    global NMEAPVT
+    global NMEARLTM
 
     StopLineProtocol
-    set NMEAPVT 0
+    set NMEARLTM 0
     return
 }
 
@@ -110,15 +126,16 @@ proc GarminStopNMEA {} {
 proc ProcNMEALine {line lxor} {
     # process a NMEA sentence
     #  $lxor is the XOR of all chars in $line (as string)
+    # return 1 on error
     global NMEAKnown NMEASent NMEAInvalid
 
     if { [regexp {[^ -~]+} $line] } {
 	Log "PNL> bad chars in: $line"
-	return
+	return 1
     }
     if { [string index $line 0] != "\$" } {
 	Log "PNL> no starting dollar in: $line"
-	return
+	return 1
     }
     set fs [split [string range $line 1 end] ","]
     set last [lindex $fs end]
@@ -130,11 +147,11 @@ proc ProcNMEALine {line lxor} {
 	    foreach code "36 42 $d1 $d2" { set lxor [expr $lxor ^ $code] }
 	    if { $lxor != $csval } {
 		Log "PNL> wrong checksum ($lxor not $csval) in: $line"
-		return
+		return 1
 	    }
 	} else {
 	    Log "PNL> bad checksum field in: $line"
-	    return
+	    return 1
 	}
 	set fs [lreplace $fs end end $field]
     }
@@ -151,13 +168,13 @@ proc ProcNMEALine {line lxor} {
 		set annex [lindex $fs $ix] ; incr ix
 	    } else { set annex "" }
 	    set val [DecodeNMEAField $type $fld $annex]
-	    if { $NMEAInvalid } { return }
+	    if { $NMEAInvalid } { return 1 }
 	    lappend data $val
-	    if { "$attr" == "time" } { set time $val }
+	    if { $attr == "time" } { set time $val }
 	}
 	CollectNMEAData $sent $time $data
     }
-    return
+    return 0
 }
 
 proc DecodeNMEAField {type field annex} {
@@ -166,7 +183,7 @@ proc DecodeNMEAField {type field annex} {
     # set NMEAInvalid on error or if the fix status is invalid
     global NMEAInvalid
 
-    if { "$field" == "" } {
+    if { $field == "" } {
 	if { [regexp {fix.*} $type] } {
 	    # Log "DNF> invalid fix; discarding sentence"
 	    set NMEAInvalid
@@ -177,9 +194,9 @@ proc DecodeNMEAField {type field annex} {
 	DMM,?/? {
 	    # DMM and heading letter -> signed degrees
 	    regexp {DMM,(.)/(.)} $type z ph nh
-	    if { "$annex" == "$ph" } {
+	    if { $annex == $ph } {
 		set sign 1
-	    } elseif { "$annex" == "$nh" } {
+	    } elseif { $annex == $nh } {
 		set sign -1
 	    } else {
 		Log "DNF> bad sign in $type: $annex, field is $field"
@@ -190,13 +207,13 @@ proc DecodeNMEAField {type field annex} {
 		Log "DNF> bad DMM value: $field"
 		set NMEAInvalid 1 ; return 0
 	    }
-	    if { "$d" == "" } { set d 0 }
+	    if { $d == "" } { set d 0 }
 	    if { $m1 == 0 } { set m $m2 } else { set m [expr 10*$m1+$m2] }
 	    return [expr $sign*($d+$m/60.0)]
 	}
 	*,=* {
 	    regexp {(.+),=(.+)} $type z t1 str
-	    if { "$annex" == "$str" } {
+	    if { $annex == $str } {
 		return [DecodeNMEAField $t1 $field ""]
 	    }
 	    Log "DNF> bad sub-field of type $type: $annex, for field $field"
@@ -255,14 +272,19 @@ proc DecodeNMEAField {type field annex} {
 
 proc DecodeNMEATimeDate {td mxs} {
     # HHMMSS or DDMMYY into list
+    # if $td has a "." then it is taken to be in HHMMXX._ format
+    #  where XX._ is seconds in %0f format
     #  $mxs are extreme values for each sub-field
     # set NMEAInvalid on error
     global NMEAInvalid
 
     if { [string length $td] == 6 } {
 	set fmt %02d%02d%02d
+    } elseif { [regexp {\.} $td] } {
+	set fmt %02d%02d%0f
     } else { set fmt %1d%02d%02d }
     if { [scan $td $fmt s1 s2 s3] == 3 } {
+	set s3 [expr round($s3)]
 	foreach v "s1 s2 s3" mx $mxs {
 	    if { [set $v] > $mx } {
 		Log "DNTD> bad time or date: [set $v] in $td"
@@ -298,8 +320,8 @@ proc CollectNMEAData {sent time data} {
 
     if { [lsearch -exact $NMEASeen $sent] != -1 } {
 	SendNMEAData $time
-    } elseif { "$time" != "undef" } {
-	if { "$NMEACurrentTime" == "undef" } {
+    } elseif { $time != "undef" } {
+	if { $NMEACurrentTime == "undef" } {
 	    set NMEACurrentTime $time
 	} elseif { $time != $NMEACurrentTime } {
 	    SendNMEAData $time
@@ -316,7 +338,7 @@ proc CollectNMEAData {sent time data} {
 	    set sp [expr [lindex $data 4]/539.9568e-3]
 	    set data [lreplace $data 4 4 $sp]
 	    set date [lindex $data 6]
-	    if { "$date" != "_" && [string match $NMEACurrentDate -*] } {
+	    if { $date != "_" } {
 		set NMEACurrentDate $date
 	    }
 	    set from "1 2 3 4 5" ; set to "2 0 1 7 8"
@@ -328,8 +350,8 @@ proc CollectNMEAData {sent time data} {
 	    set from "0 1 2" ; set to "4 5 3"
 	}
 	PGRMZ {
-	    if { "[lindex $NMEAData 6]" == "_" } {
-		set data [expr [lindex $data 0]/0.3048]
+	    if { [lindex $NMEAData 6] != "_" } {
+		set data [expr round([lindex $data 0]*0.3048)]
 		set from 0 ; set to 6
 	    } else {
 		set from ""
@@ -339,7 +361,7 @@ proc CollectNMEAData {sent time data} {
 	    set from ""
 	}
     }
-    if { "$from" != "" } { MergeNMEAData $from $data $to }
+    if { $from != "" } { MergeNMEAData $from $data $to }
     return
 }
 
@@ -349,7 +371,7 @@ proc MergeNMEAData {frixs data toixs} {
     global NMEAData
 
     foreach from $frixs to $toixs {
-	if { "[set it [lindex $data $from]]" != "_" } {
+	if { [set it [lindex $data $from]] != "_" } {
 	    set NMEAData [lreplace $NMEAData $to $to $it]
 	}
     }
@@ -358,38 +380,59 @@ proc MergeNMEAData {frixs data toixs} {
 
 proc SendNMEAData {time} {
     # send data collected to upper level if current time is defined
-    global NMEAStatus NMEAData NMEASeen NMEACurrentTime NMEACurrentDate
+    global NMEAStatus NMEAData NMEASeen NMEACurrentTime NMEACurrentDate \
+	    NMEAFrom NMEADataFile NMEADefDate NMEAPrevSecs
 
-    if { "$NMEACurrentTime" != "undef" } {
-	if { [lindex $NMEACurrentDate 0] < 0 } {
-	    scan $NMEACurrentDate "-%d %0d %0d" y m d
+    if { $NMEACurrentTime != "undef" } {
+	foreach "h m s" $NMEACurrentTime {}
+	set tsecs [expr $h*3600+$m*60+$s]
+	if { $NMEACurrentDate == "" } {
+	    if { $NMEAPrevSecs > $tsecs && [lindex $NMEADefDate 0] != 1990 } {
+		# $NMEAPrevSecs >= 0 and over midnight
+		foreach "y m d" $NMEADefDate {}
+		set NMEADefDate [clock format \
+			[clock scan "1 day" \
+			-base [clock scan ${y}-${m}-${d}]] -format "%Y %m %d"]
+	    }
 	} else {
 	    if { [scan $NMEACurrentDate "%d %d %d" d m y] != 3 } {
 		BUG "bad current date in SendNMEAData: $NMEACurrentDate"
 	    }
-	    incr y 2000
+	    if { $y < 88 } {
+		# safe up to 2087...
+		incr y 2000
+	    } else { incr y 1900 }
+	    set NMEADefDate "$y $m $d"
 	}
-	set date [concat [list $y $m $d] $NMEACurrentTime]
-	if { "[set bear [lindex $NMEAData 8]]" == "_" || \
-		"[set sp [lindex $NMEAData 7]]" == "_" } {
+	set NMEACurrentDate ""
+	if { $NMEAPrevSecs != -2 } { set NMEAPrevSecs $tsecs }
+	set date [concat $NMEADefDate $NMEACurrentTime]
+	set sp [lindex $NMEAData 7]
+	if { [set bear [lindex $NMEAData 8]] == "_" || $sp == "_" } {
 	    set vx "_" ; set vy "_"
 	} else {
 	    set a [expr $bear*0.01745329251994329576]
 	    set vx [expr $sp*cos($a)/1000.0]
 	    set vy [expr $sp*sin($a)/1000.0]
 	}
-	set pvtdata [list $date \
+	set rltmdata [list $date \
 		[list [lindex $NMEAData 0] [lindex $NMEAData 1]] \
 		$NMEAStatus([lindex $NMEAData 2]) \
 		[lrange $NMEAData 3 5] \
 		[lindex $NMEAData 6] \
 		[list $vx $vy _] \
-		$bear]
-	after 0 [list UsePVTData $pvtdata]
+		$bear "_" "_" $sp]
+	if { $NMEAFrom == "rec" } {
+	    after 0 [list UseRealTimeData $rltmdata]
+	} else {
+	    ImportNMEAData $rltmdata $NMEADataFile
+	}
+    }
+    if { $NMEAFrom == "rec" } {
+	set NMEADefDate [clock format [clock seconds] -format "%Y %m %d"]
     }
     set NMEAData "_ _ _ _ _ _ _ _ _"
     set NMEASeen "" ; set NMEACurrentTime $time
-    set NMEACurrentDate [clock format [clock seconds] -format "-%Y %m %d"]
     return
 }
 
