@@ -1,7 +1,7 @@
 #
 #  gpsman --- GPS Manager: a manager for GPS receiver data
 #
-#  Copyright (c) 2001 Miguel Filgueiras (mig@ncc.up.pt) / Universidade do Porto
+#  Copyright (c) 2004 Miguel Filgueiras (mig@ncc.up.pt) / Universidade do Porto
 #
 #    This program is free software; you can redistribute it and/or modify
 #      it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
 #      along with this program.
 #
 #  File: garmin_protocols.tcl
-#  Last change:  14 December 2001
+#  Last change:  7 June 2004
 #
 
 # description of Garmin protocols based on Garmin GPS Interface
@@ -35,7 +35,7 @@ set DLECHR [binary format "c" $DLE]
 
    # protocol tags
 array set PROTTAG {
-    P Physical  L Link  A Application  D Data
+    P Physical  L Link  A Application  D Data  T nospec
 }
 
    # application protocol categories
@@ -50,9 +50,15 @@ array set PROTCAT {
     A400  Prx
     A500  AL
     A600  DtTm
+    A601  nospec
+    A650  nospec
     A700  Posn
     A800  PVT
-    A900  undef
+    A900  nospec
+    A901  nospec
+    A902  nospec
+    A903  nospec
+    A904  nospec
 }
 
    # protocol requirements
@@ -72,8 +78,16 @@ array set PROTREQ {
     A400  PrxWPData
     A500  ALData
     A600  DtTmData
+    A601  D?
+    A650  D?
     A700  PosnData
     A800  PVTData
+    A802  D?
+    A900  ""
+    A901  D?
+    A902  ""
+    A903  ""
+    A904  ""
 }
 
    # Basic Link Protocol
@@ -83,7 +97,7 @@ set PID(PArray) 253 ; set RPID(253) PArray
 set PID(PrdReq) 254 ; set RPID(254) PrdReq
 set PID(PrdData) 255 ; set RPID(255) PrdData
 
-   # names of product specific protocols
+   # names of known product specific protocols
 set PSPROTOCOLS {Link DevCmd WP RT TR Prx AL DtTm Posn PVT}
 
    # definitions of Link product specific protocols
@@ -111,9 +125,20 @@ array set PDTSIZE {
 }
 
     # protocol data types
+
+      # data type for ACK/NAK packet; this is now set in proc FixACKNAKType
+      #  when the first such packet is received
+      # sending 16-bit int according to Garmin specifications versions < 3
+      #  but accepting either int or byte as in versions <= 3
+set PDTYPE(ACK) union=int,byte
+set PDTYPE(NAK) union=int,byte
+
+      # sending byte according to Garmin specifications version 3
+      #  and accepting either int or byte as in versions <= 3
+# set PDTYPE(ACK) union=byte,int
+# set PDTYPE(NAK) union=byte,int
+
 array set PDTYPE {
-    ACK  union=byte,int
-    NAK  union=byte,int
     PArray  starray=char,word
     PrdReq  ignored
     PrdData  {int int string ignored}
@@ -128,6 +153,8 @@ array set PDTYPE {
     D107  {charray=6 semicircle unused=4 charray=40 byte byte float byte}
     D108  {byte byte byte byte int bytes=18 semicircle float float float
            charray=2 charray=2 string string string string string string}
+    D109  {byte byte byte byte int bytes=18 semicircle float float float
+           charray=2 charray=2 long string string string string string string}
     D150  {charray=6 charray=2 byte semicircle int charray=24 charray=2
 	   charray=30 charray=40}
     D151  {charray=6 semicircle unused=4 charray=40 float charray=30
@@ -151,11 +178,18 @@ array set PDTYPE {
     D501  {int float float float float float float float float float float
            byte}
     D600  {byte byte word int byte byte}
+    D601  nospec
+    D650  nospec
     D700  radian
     D800  {float float float float int double radian float float float float
            int long}
+    D802  nospec
+    D901  nospec
 }
 
+## RT Header protocols with a numeric identifier
+set PRTNUMID {D200 D201}
+
     # product identifiers; new entries should also be added to recmodels.tcl
     #  numbers followed by a letter are defined here to support older
     #  software versions; not following Garmin specs in this
@@ -212,12 +246,27 @@ array set PRODID {
     "GPS 12CX" 116
     "GPS III Plus" 119
     "GPSMAP 295" 128
+    "GPS 12 Map" 129
     eTrex  130
+    "GPS 12 4.58" 138
     "eTrex Summit"  141
+    "GPSMAP 196" 145
+    "StreetPilot 3" 151
     "eTrex Venture/Mariner"  154
+    "GPS 5"  155
     "eTrex Euro"  156
     "eTrex Vista" 169
+    "GPS 76" 173
+    "GPSMAP 76" 177
     "eTrex Legend" 179
+    "GPSMAP 76S" 194
+    "Rino 110"   197
+    "Rino 120"   209
+    "GPS 72" 247
+    "Geko 201" 248
+    "Geko 301" 256
+    "GPSMap60C" 291
+    "ForeTrex" 314
 }
 
     # product names and how to obain its product specific protocols
@@ -276,12 +325,27 @@ array set PNAME {
     111  eMap
     116  "GPS 12CX"
     128  "GPSMAP 295"
+    129  "GPS 12 Map"
     130  eTrex
+    138  "GPS 12"
     141  "eTrex Summit"
+    145  "GPSMAP 196"
+    151  "StreetPilot 3"
     154  "eTrex Venture/Mariner"
+    155  "GPS 5"
     156  "eTrex Euro"
     169  "eTrex Vista"
+    173  "GPS 76"
+    177  "GPSMAP 76"
     179  "eTrex Legend"
+    194  "GPSMAP 76S"
+    197  "Rino 110"
+    209  "Rino 120"
+    247  "GPS 72"
+    248  "Geko 201"
+    256  "Geko 301"
+    291  "GPSMap60C"
+    314  "ForeTrex"
 }
 
 # the descriptions below are valid for all versions except:
@@ -289,6 +353,17 @@ array set PNAME {
 #  36 version >= 3.0; for older versions see=22
 #  77 version >= 3.61; may work for some older versions
 #  77a defined for 77 version < 3.01
+#  111 version <= 2.7
+#  111a version > 2.7
+
+      # the pairs in the following entries have a comparison to be made
+      #  to the receiver version and the identifier to be used if the
+      #  comparison succeeds
+array set PRTCLVERSION {
+    36  {{{< 300} 22}}
+    77  {{{< 301} 77a}}
+    111 {{{> 270} 111a}}
+}
 
 array set PRTCLDEF {
     13  diff
@@ -333,15 +408,31 @@ array set PRTCLDEF {
     105  see=77
     106  see=77
     111  array
+    111a diff
     116  array
     119  array
     128  see=111
+    129  array
     130  diff
+    138  see=77
     141  see=130
+    145  array
+    151  array
     154  see=130
+    155  diff
     156  see=130
     169  see=130
+    173  see=177
+    177  array
     179  see=130
+    194  see=177
+    197  see=177
+    209  see=177
+    247  see=116
+    248  array
+    256  diff
+    291  array
+    314  array
 }
 
 ### there is no information on which receivers use the PVT protocol
@@ -427,6 +518,159 @@ array set PSPID {
     119,PosnData  D700
     119,PVT  A800
     119,PVTData D800
+
+    129,Link  L001
+    129,DevCmd  A010
+    129,WP  A100
+    129,WPData  D104
+    129,RT  A200
+    129,RTHeader  D201
+    129,RTWPData  D104
+    129,TR  A300
+    129,TRData  D300
+    129,Prx  N/A
+    129,AL  A500
+    129,ALData  D501
+    129,DtTm  A600
+    129,DtTmData  D600
+    129,Posn  A700
+    129,PosnData  D700
+    129,PVT  A800
+    129,PVTData D800
+    129,nospec A900
+
+    145,Link  L001
+    145,DevCmd  A010
+    145,WP  A100
+    145,WPData  D109
+    145,RT  A201
+    145,RTHeader  D202
+    145,RTWPData  D109
+    145,RTLinkData  D210
+    145,TR  A301
+    145,TRHeader  D310
+    145,TRData  D301
+    145,Prx  A400
+    145,PrxWPData  D109
+    145,AL  A500
+    145,ALData  D501
+    145,DtTm  A600
+    145,DtTmData  D600
+    145,Posn  A700
+    145,PosnData  D700
+    145,PVT  A800
+    145,PVTData  D800
+    145,nospec  A650+D650+A900+A901+D901+A902+A903+A904
+
+    151,Link  L001
+    151,DevCmd  A010
+    151,WP  A100
+    151,WPData  D109
+    151,RT  A201
+    151,RTHeader  D202
+    151,RTWPData  D109
+    151,RTLinkData  D210
+    151,TR  A301
+    151,TRHeader  D310
+    151,TRData  D301
+    151,Prx  N/A
+    151,AL  A500
+    151,ALData  D501
+    151,DtTm  A600
+    151,DtTmData  D600
+    151,Posn  A700
+    151,PosnData  D700
+    151,PVT  A800
+    151,PVTData  D800
+    151,nospec  A900+A902+A903+A904
+
+    177,Link  L001
+    177,DevCmd  A010
+    177,WP  A100
+    177,WPData  D109
+    177,RT  A201
+    177,RTHeader  D202
+    177,RTWPData  D109
+    177,RTLinkData  D210
+    177,TR  A301
+    177,TRHeader  D310
+    177,TRData  D301
+    177,Prx  A400
+    177,PrxWPData D109
+    177,AL  A500
+    177,ALData  D501
+    177,DtTm  A600
+    177,DtTmData  D600
+    177,Posn  A700
+    177,PosnData  D700
+    177,PVT  A800
+    177,PVTData D800
+    177,nospec A900+A902+A903
+
+    248,Link L001
+    248,DevCmd A010
+    248,WP A100
+    248,WPData D108
+    248,RT A201
+    248,RTHeader D202
+    248,RTWPData D108
+    248.RTLinkData D210
+    248,TR A301
+    248,TRHeader D310
+    248,TRData D301
+    248,Prx  N/A
+    248,AL A500
+    248,ALData D501
+    248,DtTm A600
+    248,DtTmData D600
+    248,Posn A700
+    248,PosnData D700
+    248,PVT A800
+    248,PVTData D800
+
+    291,Link L001
+    291,DevCmd A010
+    291,WP A100
+    291,WPData D109
+    291,RT A201
+    291,RTHeader D202
+    291,RTWPData D109
+    291,RTLinkData D210
+    291,TR A301
+    291,TRHeader D310
+    291,TRData D301
+    291,Prx A400
+    291,PrxWPData D109
+    291,AL A500
+    291,ALData D501
+    291,DtTm A600
+    291,DtTmData D600
+    291,Posn A700
+    291,PosnData D700
+    291,PVT A800
+    291,PVTData D800
+    291,nospec A601+D601+A900+A902+A903
+
+    314,Link L001
+    314,DevCmd A010
+    314,WP A100
+    314,WPData D108
+    314,RT A201
+    314,RTHeade D202
+    314,RTWPData D108
+    314,RTLinkData D210
+    314,TR A301
+    314,TRHeader D310
+    314,TRData D301
+    314,AL A500
+    314,ALData D501
+    314,DtTm A600
+    314,DtTmData D600
+    314,Posn A700
+    314,PosnData D700
+    314,PVT A800
+    314,PVTData D800
+    314,nospec A802+D802+A903
 }
 
           # must not differ on the Link and DevCmd protocols
@@ -448,6 +692,9 @@ array set PSDIFF {
     77  {73 {Prx A400} {PrxData D403}}
     77a {59 {ALData D501}}
     130 {111 {RTHeader D202}}
+    111a {111 {WPData D109} {RTWPData D109} {PrxWPData D109}}
+    155 {145 {nospec A900+A902+A903+A904}}
+    256 {248 {nospec A802}}
 }
 
 ## descriptions, positions in Garmin structures of GPSMan data
@@ -480,6 +727,9 @@ array set DATAFOR {
     D108,ns {DispOpt Symbol Posn Alt Name Commt}
     D108,ps {2 4 6 7 12 13}
 
+    D109,ns {DispOpt Symbol Posn Alt Name Commt}
+    D109,ps {2 4 6 7 13 14}
+
     D150,ns {Name Posn Alt Commt}
     D150,ps {0 3 4 8}
 
@@ -494,10 +744,24 @@ array set DATAFOR {
 
     D155,ns {Name Posn Commt Alt Symbol DispOpt}
     D155,ps {0 1 3 8 12 13}
+
+    D310,ns {Colour Name}
+    D310,ps {0 2}
 }
 
-## descriptions, types, default values, positions in Garmin structures, and
-#   constraints of hidden attributes
+## colours: names (as in rgb.tcl) ordered as in a C enumeration according to
+#   Garmin value, and name of global variable containing default value
+
+array set GARMINCOLOURS {
+    D310 {black darkred darkgreen darkyellow darkblue darkmagenta darkcyan
+          lightgray darkgray red green yellow blue magenta cyan white}
+    D310,dvar DEFTTRCOLOUR
+}
+
+## hidden attributes:
+#   names, types, default values, positions in Garmin structures,
+#   constraints of hidden attributes and (possibly) preprocessing info
+#   and formatting info (see proc HiddenFormatVal)
 
  # positions must be in increasing order!
  # constraints assume that all attributes have been assigned to variables
@@ -509,12 +773,14 @@ array set HIDDENFOR {
     D106,vs {0 0 ""}
     D106,ps {0 1 5}
     D106,cs { { if { $class==0 } { lappend undef subclass } } }
+    D106,fm {{class enumd {user non_user}}}
 
     D107,ns {colour}
     D107,ts {byte}
     D107,vs {0}
     D107,ps {7}
     D107,cs {}
+    D107,fm {{colour enum {default red green blue}}}
 
     D108,ns {class colour attrs subclass depth state country facility
     city addr int_road}
@@ -530,6 +796,42 @@ array set HIDDENFOR {
 	{ if { $class!=0x83 } { lappend undef addr } }
 	{ if { $class!=0x82 } { lappend undef int_road } }
     }
+    D108,fm {{class envals {{0 user} {0x40 avn_airport} {0x41 avn_inters}
+                            {0x42 avn_NDB} {0x43 avn_VOR}
+			    {0x44 avn_airp_rway} {0x45 avn_airp_int}
+			    {0x46 avn_airp_NDB} {0x80 map_pt}
+			    {0x81 map_area} {0x82 map_int}
+			    {0x83 map_addr} {0x84 map_label}
+			    {0x85 map_line}}}
+	     {colour enumd {black dark_red dark_green dark_yellow dark_blue
+			    dark_magenta dark_cyan light_gray dark_gray
+			    red green yellow blue magenta cyan white default}}}
+
+    D109,ns {dtyp class colour attrs subclass depth state country ete facility
+    city addr int_road}
+    D109,ts {byte byte byte byte bytes=18 float charray=2 charray=2
+    long string string string string}
+    D109,vs {1 0 0x1f 0x70
+    "0 0 0 0 0 0 255 255 255 255 255 255 255 255 255 255 255 255"
+    1.0e25 "" "" 0xffffffff "" "" "" ""}
+    D109,ps {0 1 2 3 5 8 10 11 12 15 16 17 18}
+    D109,cs {
+	{ if { $class==0 || $class>0x46 } { lappend undef city facility } }
+	{ if { $class<0x80 } { lappend undef subclass } }
+	{ if { $class!=0x83 } { lappend undef addr } }
+	{ if { $class!=0x82 } { lappend undef int_road } }
+    }
+    D109,pp {{colour &0x1f}}
+    D109,fm {{class envals {{0 user} {0x40 avn_airport} {0x41 avn_inters}
+                            {0x42 avn_NDB} {0x43 avn_VOR}
+			    {0x44 avn_airp_rway} {0x45 avn_airp_int}
+			    {0x46 avn_airp_NDB} {0x80 map_pt}
+			    {0x81 map_area} {0x82 map_int}
+			    {0x83 map_addr} {0x84 map_label}
+			    {0x85 map_line}}}
+	     {colour enumd {black dark_red dark_green dark_yellow dark_blue
+			    dark_magenta dark_cyan light_gray dark_gray
+			    red green yellow blue magenta cyan white default}}}
 
     D150,ns {country class city state facility}
     D150,ts {charray=2 byte charray=24 charray=2 charray=30}
@@ -538,6 +840,8 @@ array set HIDDENFOR {
     D150,cs {
 	{ if { $class==4 } { lappend undef city state country facility } }
     }
+    D150,fm {{class enum {avn_airport avn_inters avn_NDB avn_VOR user
+                          avn_airp_rway avn_airp_int locked}}}
 
     D151,ns {facility city state country class}
     D151,ts {charray=30 charray=24 charray=2 charray=2 byte}
@@ -546,6 +850,7 @@ array set HIDDENFOR {
     D151,cs {
 	{ if { $class==2 } { lappend undef city state country facility } }
     }
+    D151,fm {{class enum {avn_airport avn_VOR user locked}}}
 
     D152,ns {facility city state country class}
     D152,ts {charray=30 charray=24 charray=2 charray=2 byte}
@@ -554,6 +859,7 @@ array set HIDDENFOR {
     D152,cs {
 	{ if { $class==4 } { lappend undef city state country facility } }
     }
+    D152,fm {{class enum {avn_airport avn_inters avn_NDB avn_VOR user locked}}}
 
     D154,ns {facility city state country class}
     D154,ts {charray=30 charray=24 charray=2 charray=2 byte}
@@ -562,6 +868,9 @@ array set HIDDENFOR {
     D154,cs {
 	{ if { $class==4 } { lappend undef city state country facility } }
     }
+    D154,fm {{class enum {avn_airport avn_inters avn_NDB avn_VOR user
+                          avn_airp_rway avn_airp_int avn_airp_NDB user_symbol
+                          locked}}}
 
     D155,ns {facility city state country class}
     D155,ts {charray=30 charray=24 charray=2 charray=2 byte}
@@ -570,6 +879,7 @@ array set HIDDENFOR {
     D155,cs {
 	{ if { $class==4 } { lappend undef city state country facility } }
     }
+    D155,fm {{class enum {avn_airport avn_inters avn_NDB avn_VOR user locked}}}
 
     D210,ns {class subclass}
     D210,ts {word bytes=18}
@@ -578,12 +888,30 @@ array set HIDDENFOR {
     D210,cs {
 	{ if { $class==3 || $class==0xff } { lappend undef subclass } }
     }
+    D210,fm {{class enum {line link net direct snap}}}
 
-    D310,ns {colour display}
-    D310,ts {byte boolean}
-    D310,vs {255 0}
-    D310,ps {0 1}
+    D310,ns {display}
+    D310,ts {boolean}
+    D310,vs {0}
+    D310,ps {1}
     D310,cs {}
+    D310,fm {{display enumd {no  yes}}}
+}
+
+# no longer used hidden attributes
+#   type, name in FATTRPAIRS array (see files.tcl), and
+#   conversion code from Garmin value to GPSMan value
+
+ # conversion code assumes that
+ #  - each attribute value have been assigned to a variable with same name
+ #  as the attribute
+ #  - each such variable is set to the converted value
+ #  - the variable $default has been assigned to the default value
+
+array set OLDHIDDENFOR {
+    D310:colour {byte colour
+	{ set colour [FromGarminColour D310 $colour] }
+    }
 }
 
 ### PVT status for D800
