@@ -1,7 +1,7 @@
 #
 #  gpsman --- GPS Manager: a manager for GPS receiver data
 #
-#  Copyright (c) 2002 Miguel Filgueiras (mig@ncc.up.pt) / Universidade do Porto
+#  Copyright (c) 2004 Miguel Filgueiras (mig@ncc.up.pt) / Universidade do Porto
 #
 #    This program is free software; you can redistribute it and/or modify
 #      it under the terms of the GNU General Public License as published by
@@ -17,11 +17,14 @@
 #      along with this program.
 #
 #  File: langengl.tcl
-#  Last change:  5 February 2002
+#  Last change:  1 June 2004
 #
 # French language file by Valre Robin (valere.robin@wanadoo.fr)
 #  Last change by him:  11 November 2001
-#  last input from him inserted:  27 November 2001
+#  last input from him inserted:  1 June 2004
+#
+# Includes contributions by Jean H Theoret (ve2za@rac.ca)
+# Includes typo corrections by Laurent Bonnaud (bonnaud@lis.inpg.fr)
 #
 
 # file langengl.tcl is consulted first; no need for duplicating entries here
@@ -37,40 +40,44 @@ set DLUNIT(NAUTMILE,dist) "mn"
 set DLUNIT(NAUTMILE,area) "mn2"
 set DLUNIT(NAUTMILE,speed) noeud
 
+set DLUNIT(M,dist) $DLUNIT(KM,subdist)
+set DLUNIT(FT,dist) $DLUNIT(STATMILE,subdist)
+
 set DTUNIT $DLUNIT($DISTUNIT,dist)
 set SPUNIT $DLUNIT($DISTUNIT,speed)
+set ARUNIT $DLUNIT($DISTUNIT,area)
+set ALUNIT $DLUNIT($ALTUNIT,dist)
 
-set MESS(RTcomp) "#\tWP\t\t$DTUNIT\tdeg\m"
-set MESS(TRcomp) "#\t$DTUNIT\t$DTUNIT\tm\th:m:s\t$SPUNIT\tdeg"
+set MESS(RTcomp) "#\tWP\t\t$DTUNIT\tdeg\t$ALUNIT"
+set MESS(TRcomp) "#\t$DTUNIT\t$DTUNIT\t$ALUNIT\th:m:s\t$SPUNIT\tdeg"
 set MESS(WPNearest) "WP\t\t$DTUNIT\tdeg"
 
 array set MESS {
-    notleap   "YEAR0 dfinie comme %d n'est pas une anne bissextile"
     badscale   "Valeur errone pour l'chelle de la carte"
     oktoexit   "Ok pour quitter (les donnes non sauves vont tre perdues)"
     okclrmap   "Ok pour effacer la carte"
     namelgth   "Le nom ne doit pas dpasser %d caractres"
     cmmtlgth   "=== Un commentaire ne peut dpasser %d caractres"
     namevoid   "Le nom ne peut tre vide"
-    baddate   "Mauvais date"
+    baddate   "Date errone"
     badhdg   "Mauvais en-tte %s: doit tre %s ou +/-"
-    badcoord   "Mauvais format ou interval de coordonnes: \"%s\" doit tre %s"
+    badcoord   "Mauvais format ou intervalle de coordonnes: \"%s\" doit tre %s"
     outofrng   "Nombre non valide"
     UTMZN   "Doit tre une lettre parmi A..H, J..N, ou P..Z"
     badstrg "Caractre(s) erron(s)"
-    strgvoid   "Une chine de caractre ne peut tre vide"
+    strgvoid   "Une chane de caractre ne peut tre vide"
     nan   "\"%s\" n'est pas un nombre"
-    written   "Ecrit par"
+    written   "crit par"
     undefWP   "L'itinraire %s a des points (WPs) non dfinis; non sauv ou export"
     bigRT   "Itinraire %s > nombre max; non export"
     unkndatum   "Donne inconnue"
     badcommdWP   "Mauvaise commande en chargeant les WPs; ligne"
     notabsWP   "Mauvaise dfinition d'un point d'itinraire; pas de tabulation, ligne"
-    undefWP   "Rfrence  un point d'itinraire inconnu: %s; ligne %d"
+    undefinedWP   "Rfrence  un point d'itinraire inconnu: %s"
     nofieldsWP   "Mauvais point d'itinraire, pas assez de champs; ligne"
     excfieldsWP  "Mauvais point d'itinraire, trop de champs; ligne"
     badWPsRT   "Route avec une liste de points d'itinraire errone; ligne"
-    toomuchWPs   "Warning: plus de %d points dans l'itinraire"
+    toomuchWPs   "Attention: plus de %d points dans l'itinraire"
     badcommdTP   "Mauvaise commande lors du chargement de TPs; ligne"
     badTP    "Mauvais point dans la trace; ligne"
     badTPsTR   "Trace avec une liste errone de points; ligne"
@@ -91,9 +98,9 @@ array set MESS {
     cantmapRTunkn   "La route n'est pas sur la carte; pas d'info sur point d'itinraire"
     cantmapRTed   "La route n'est pas sur la carte; point d'itinraire en cours d'dition"
     cantrun   "Excution impossible"
-    inprogr   "Operation en cours"
-    cantread   "Lecture du fichier auxilliaire impossible"
-    cantwrtopt   "Ecriture du fichier de prfrence impossible"
+    inprogr   "Opration en cours"
+    cantread   "Lecture du fichier auxiliaire impossible"
+    cantwrtopt   "criture du fichier de prfrence impossible"
     voidRT   "La route ne contient pas de points"
     activeRT   "La route 0 est active; continuer?"
     voidTR   "La trace ne contient pas de points"
@@ -103,7 +110,7 @@ array set MESS {
     askforget   "Oubli de ce %s?"
     notimpl   "Non implment"
     forgetall   "Oubli de tous les lments %s de la liste?"
-    counted   "Il y a %d %ss defini(e)s"
+    counted   "Il y a %d %ss dfini(e)s"
     notlisted   "Item non list"
     wrgval   "Valeur errone pour"
     voidGR   "Le groupe n'a pas d'lment."
@@ -111,7 +118,7 @@ array set MESS {
     GRelout   "La commande pour GR est hors d'une dfinition; ligne"
     badGRels   "Groupe avec une mauvaise liste d'lments; ligne"
     badcommdGRel   "Commande errone lors du chargement d'lments GR; ligne"
-    notypeforGRel   "Elment sans type; ligne"
+    notypeforGRel   "lment sans type; ligne"
     badGRel   "Mauvaise dfinition d'lment; ligne"
     check   "Connexion en cours de vrification"
     toomanyerr   "Erreurs trop nombreuses; abandon..."
@@ -119,7 +126,7 @@ array set MESS {
     getRT   "Acquisition des routes"
     getTR   "Acquisition des traces"
     putWP   "Chargement des points d'itinraire"
-    putRT   "Chargement des poutes"
+    putRT   "Chargement des routes"
     putTR   "Chargement des traces"
     fillbuffWP  "Chargement des buffers de point d'itinraire"
     fillbuffRT  "Chargement des buffers de RT"
@@ -128,27 +135,23 @@ array set MESS {
     badserial "Ouverture du port srie %s impossible"
     nodata    "Pas de %ss dans le rcepteur"
     badimage "Fichier image erron"
-    mapaskWPs "Choisir les %d points d'itinraire  placer sur la carte"
     mapadjust "Placer les points d'itinraire sur la carte puis cliquer sur Ok"
     duplicate "%s est dj slectionn"
     clrcurrmap "Effacement de la carte courante?"
-    cantfix "%d point sont ncessaires pour fixer la carte; commencer par charger ou dfinir des points d'itinraire"
     mbkbaddatum "Donnes absentes ou inconnues"
     mbkbadscale "L'chelle ne doit pas tre ngative"
     mbkbadat "Arguments errons"
-    edityourrisk "Editez  vos risques!"
+    edityourrisk "ditez  vos risques!"
     okclrbkmap   "Ok pour effacer le fond de carte"
     okclrbkim    "Ok pour effacer l'image "
-    badWPfield "Champs optionnel erron"
-    badWPattr "Nom de champs optionnel inconnu"
     badSYMBOLcode "Code de symbole erron"
     badDISPOPTcode "Code d'option d'affichage erron"
     goingdown "Prfrences sauvegardes; redmarrer"
-    putwhat "Ecriture de quel type d'item?"
+    putwhat "criture de quel type d'item?"
     readwhat "Lecture de quel type d'item?"
     noWPinx "Trop de points d'itinraire pour le rcepteur"
-    noICinx "Trops d'icnes pour le rcepteur"
-    getIC "Rception des icones"
+    noICinx "Trop d'icnes pour le rcepteur"
+    getIC "Rception des icnes"
     serial1 "Prambule de l'en-tte erron"
     serial2 "Commande incorrecte"
     checksum1 "Checksum de l'en-tte erron"
@@ -164,7 +167,7 @@ array set MESS {
     badangle "L'angle doit tre compris entre 0 et 360 degrs"
     georefhow  "Mthode de go-rfrencement"
     cantsolve  "Rsolution de l'quation impossible"
-    transfcantscale "Echelle absente dans la transformation courante"
+    transfcantscale "chelle absente dans la transformation courante"
     oldfilefmt "Format de fichier prim ; merci de sauver dans le nouveau format de fichier"
     unknProj "Projection de la carte inconnue"
     unknTransf "Transformation de la carte inconnue"
@@ -186,16 +189,16 @@ array set MESS {
     nohidden "Suppression des donnes caches?"
     badRS "Itinraire en dehors de la route dfinie; ligne"
     badWPsRSs "Itinraire avant le premier ou aprs le dernier WP; ligne"
-    windowdestr "La fentre at dtruite!"
+    windowdestr "La fentre a t dtruite!"
     badhidden "Format errone pour les donnes caches"
-    replname "Remplacer \"%s\" par un nom ayant au plus %d caractres parmis \"%s\""
+    replname "Remplacer \"%s\" par un nom ayant au plus %d caractres parmi \"%s\""
     badalt "Valeur errone pour l'altitude"
     baddistunit "Unit de distance errone pour l'chelle de la carte dans le fichier de prfrences"
     badgridzone "Zone de grille errone"
     outofgrid "Position en dehors du domaine de la grille"
     timeoffnotint "La valeur de temps doit tre un entier"
     cantchkprot "Vrification impossible avec le protocole courant"
-    mustconn1st "Connection avec le rcepteur  vrifier"
+    mustconn1st "Connexion avec le rcepteur  vrifier"
     rltmnotsupp "Journalisation en temps rel non supporte par ce rcepteur"
     createdir "Crer un rpertoire %s et redmarrer"
     oktomkdir "Accord pour crer le rpertoire %s?"
@@ -208,16 +211,16 @@ array set MESS {
     cantchggriddatum "La grille ncessite la donne %s"
     gridinuse "Grille utilise par %s, ne peut pas tre dtruite; continuer?"
     gridinusenochg "Grille utilise par %s; modification non prise en compte"
-    cantwrtprgr "Ecriture impossible du fichier des projections utilisateur"
-    cantwrtdtel "Ecriture impossible du fichier des donnes utilisateur"
+    cantwrtprgr "criture impossible du fichier des projections utilisateur"
+    cantwrtdtel "criture impossible du fichier des donnes utilisateur"
     movingWP "Placer %s avec le bouton gauche\nAbandonner avec le bouton droit"
     missingdata "Pas assez de donnes!"
     needs1wp "L'itinraire doit contenir au moins un point"
     emptypos "Position avec des champs vides"
-    cantwrtsstate "Ecriture impossible du fichier de sauvegarde d'tat: %s"
+    cantwrtsstate "criture impossible du fichier de sauvegarde d'tat: %s"
     cantrdsstate "Lecture impossible du fichier de sauvegarde d'tat: %s"
     corruptsstate "Fichier de sauvegarde d'tat corrompu: %s"
-    editrisk "Editez  vos risques!"
+    editrisk "ditez  vos risques!"
     savestate "Sauvegarde de l'tat courant?"
     delsstate "Destruction des fichiers de sauvegarde d'tat?"
     badmapinfo "Mauvais fichier de paramtres de carte"
@@ -225,16 +228,53 @@ array set MESS {
     areais "L'aire du polygone (ne se recoupant pas) est %.3f%s"
     areatoosmall "L'aire est trop petite (<0.001 km2)"
     projarea "Calcul de l'aire projete"
-    selfintsct "Rptition d'un point : la route ne peut pas se recouper!"
+    selfintsct "Rptition d'un point : la route ne doit pas se recouper!"
     badinvmdist "Erreur d'approximation dans l'inversion de la distance mridienne"
     badinvproj "Erreur d'approximation dans l'inversion de la projection %s"
-    negdlatlong "Interval lat/long erron : ne peut tre negative!"
+    negdlatlong "Intervalle lat/long erron : ne peut tre negatif!"
     allundef "Dfinitions manquantes pour les points du groupe"
     badfloats "Erreurs dans la conversion en virgule flottante; connecter tout de mme?"
+    noprintcmd "Commande d'impression absente;  positionner dans les options"
+    cantexecasroot "GPSMan ne peut tre excut par le super-utilisateur ROOT"
+    badargtofunc "Argument erron pour la fonction %s"
+    redefproj "La projection %s dfinie par l'utilisateur efface une projection prdfinie ayant le mme nom abrg ; dfinition  modifier!"
+    badattr "Champ optionnel inconnu pour %s :  %s"
+    badattrval "Champ optionnel erron pour %s : %s "
+    couldntcd "chec du changement de rpertoire %s"
+    shpext "Mauvaise extension %s; utilisation de .shp, .shx, .dbf?"
+    shpcntopen "Cration/Ouverture du fichier de profil impossible"
+    shpcntcrtfs "Cration des champs .dbf du profil impossible"
+    shpcntwrtfs "criture des champs .dbf du profil impossible"
+    shpoutmem "Saturation mmoire!"
+    shpemptyfile "Fichier vide"
+    shpwrongfile "Type de fichier invalide"
+    shplessdim "Nombre de dimensions insuffisant dans le fichier; continuer?"
+    shpbadWPinRT "%d-ime WP aux coordonnes errones ignors dans la route %s"
+    badGTMvers "Version du fichier GTrackMaker inacceptable"
+    badGTMfile "Chane initiale errone dans le fichier GTrackMake"
+    badGTMcounts "Nombre(s) ngatif(s) dans le fichier GTrakMake"
+    badGTMlat "Dbordement de la latitude dans le fichier GTrackMaker"
+    badGTMlong "Dbordement de la longitude dans le fichier GTrackMaker"
+    badGTMdatum "Mauvaise donne dans le fichier GTrackMaker"
+    unobscmap "Erreur probablement cause par le recouvrement de la carte par une icne ou une fentre: recommencer aprs un dlai."
+    cantwrtimg "Erreur d'criture dans un fichier au format %s"
+    TRsimplres "Cration d'une trace simplifie %s"
+    cantsaveRTid "Route %s non sauvegarde : identifiant non numrique"
+    badtrvconf "Configuration corrompue; recommencer avec une configuration vide"
+    drvsimoff "Simulateur de conduite : pas encore dmarr"
+    needWP "Simulateur de conduite : charger ou dfinir des points de route"
+    chgrecprot "Changer le protocole du rcepteur"
+    frgetGRcs "Oubli du groupe et de tous ses lments?"
+    clrtrvlog "Effacement du journal de voyage?"
+    nmeainuse "Capture en temps-rel ou lecture d'un fichier NMEA en cours"
+    badfile "Erreur lors de la lecture d'un fichier"
+    RTnoWPname "Un point d'une route ne peux plus tre dsign uniquement par son nom"
+    distlarge "Distance trop grande!"
+    timeconsmg "Opration potentiellement longue: continuer?"
 }
 
-set TXT(RTcompflds) "# WP {$DTUNIT} deg m stage label"
-set TXT(TRcompflds) "TP {$DTUNIT} {$DTUNIT} m h:m:s {$SPUNIT} deg"
+set TXT(RTcompflds) "# WP {$DTUNIT} deg {$ALUNIT} stage label"
+set TXT(TRcompflds) "TP {$DTUNIT} {$DTUNIT} {$ALUNIT} h:m:s {$SPUNIT} deg"
 set TXT(starttoend) "Dpart: vers la fin %s $DTUNIT;"
 set TXT(startmax) "max %s $DTUNIT;"
 set TXT(WPnearflds) "WP {$DTUNIT} deg"
@@ -263,13 +303,13 @@ array set TXT {
     exportto   "Exportation vers"
     count   Comptage
     trueN   "Nord vrai"
-    automagn   "Auto Magnetique"
+    automagn   "Auto Magntique"
     usrdef   "Dfini par l'utilisateur"
     nameWP   Point
     nameRT   Route
     nameTR   Trace
     nameGR   Groupe
-    namePlot Plot
+    namePlot Graphique
     nameMap  Carte
     nameRTComp   "Calcul de route"
     nameTRComp   "Calcul de trace"
@@ -288,7 +328,7 @@ array set TXT {
     message   Message
     cancel   Abandon
     file   Fichier
-    ovwrt   Ecraser
+    ovwrt   craser
     app   Ajout
     onligne   "en ligne"
     offligne  "hors ligne"
@@ -313,7 +353,7 @@ array set TXT {
     route   Route
     number   Nombre
     insb   "Insrer avant"
-    insa   "Insrer apprs"
+    insa   "Insrer aprs"
     del   Dtruire
     repl   "Remplacer par"
     comp   Calculer
@@ -325,7 +365,6 @@ array set TXT {
     chophd   "Supprimer avant"
     choptl   "Supprimer aprs"
     incb   "Inclure avant"
-    mkRT   "Faire une route"
     date   Date
     newdate   "Nouvelle date pour le point suivant"
     endprTR   "Fin de la trace prcdente"
@@ -345,7 +384,7 @@ array set TXT {
     change   Changer
     forget   Oublier
     others   Autres
-    opt_Interf  Interface
+    opt_Interf  "Interface utilisateur"
     optLANG   Langage
     optISOLATIN1   "Caractres composs"
     optDELETE   "DEL efface le dernier caractre"
@@ -356,7 +395,7 @@ array set TXT {
     optINTERVAL "Intervale d'chantillonage"
     optCOMMENTLENGTH   "Longueur maximale pour un commentaire"
     optMAXWPOINTS   "Nombre max des points d'itinraire"
-    optMAXROUTES   "Mombre max de routes"
+    optMAXROUTES   "Nombre max de routes"
     optMAXWPINROUTE   "Nombre max de points dans une route"
     optMAXTPOINTS   "Nombre max de points dans une trace"
     optCREATIONDATE   "L'enregistrement a une date de cration"
@@ -379,12 +418,12 @@ array set TXT {
     STATMILE    "mile"
     optPositionFormat   "Format de position"
     optDateFormat   "Format de date"
-    opt_Geom   "Gometrie des fentres"
+    opt_Geom   "Gomtrie des fentres"
     opt_MapGeom   "Gomtrie des cartes"
     optMAPWIDTH   "Largeur de carte"
     optMAPHEIGHT   "Hauteur de la carte"
     optMAPSCLENGTH   "Longueur de l'chelle"
-    optMAPSCALE   "Echelle de la carte"
+    optMAPSCALE   "chelle de la carte"
     optMAXMENUITEMS   "Nombre maximum d'lments par menu"
     optLPOSX   "Abscisse de la fentre des listes"
     optLPOSY   "Ordonne de la fentre des listes"
@@ -422,7 +461,7 @@ array set TXT {
     optMAPCOLOUR,anim  "Animation sur la carte"
     optMAPCOLOUR,emptygrid  "Image vide"
     optMAPCOLOUR,fullgrid   "Image existante"
-    opt_Files Fichiers
+    opt_Files "Port srie et fichiers"
     optDEFSPORT "Port Srie"
     optSAVESTATE "Sauvegarde de l'tat en quittant"
     optDELSTATE "Destruction des fichiers aprs avoir restaur l'tat"
@@ -435,13 +474,13 @@ array set TXT {
     permgroup   Groupe
     others   Autres
     fread   Lecture
-    fwrite   Ecriture
+    fwrite   criture
     fexec   Excution
     YYYYMMDD   AAAAMMJJ
     MMDDYYYY   MMJJAAAA
     DDMMMYYYY   JJMMAAAA
     YYYY-MM-DD  AAAA-MM-JJ
-    mainwd   "Fentre principate"
+    mainwd   "Fentre principale"
     distazim   "Distance et direction"
     nearestWPs   "Points les plus proches"
     fromto   "De %s  %s"
@@ -452,12 +491,11 @@ array set TXT {
     forthisWP   "pour ce point d'itinraire"
     formappedWPs   "pour les points d'itinraire sur la carte"
     group   Groupe
-    element   Elment
+    element   lment
     insert   Insertion
     joinGR   "Joindre au groupe"
     TRtoRT   "Conversion de trace en route"
     TRRTnpoints   "Nombre de points  garder"
-    TRRTdispl   "Affichage de la route"
     TRTRdispl   "Affichage de la trace"
     WP   WP
     RT   RT
@@ -530,10 +568,10 @@ array set TXT {
     SYcar_rental "Location de vhicule"
     SYcar_repair "Garage"
     SYcasino "Casino"
-    SYcastle "Chateau"
+    SYcastle "Chteau"
     SYcemetery "Cimetire"
     SYchapel "Chapelle"
-    SYchurch "Eglise"
+    SYchurch "glise"
     SYcircle_x "Rond avec un X"
     SYcivil "Civil location"
     SYcontrolled "Aire rglemente"
@@ -565,7 +603,7 @@ array set TXT {
     SYgeo_name_water "Nom topographique, eau"
     SYglider "Planeur"
     SYgolf "Golf"
-    SYheliport "Heliport"
+    SYheliport "Hliport"
     SYhorn "Corne"
     SYhouse "Maison"
     SYice_skating "Patinoire"
@@ -573,8 +611,8 @@ array set TXT {
     SYintersection "Intersection"
     SYis_highway "Autoroute"
     SYknife_fork "Nourriture"
-    SYladder "Echelle"
-    SYlanding "Atterissage"
+    SYladder "chelle"
+    SYlanding "Atterrissage"
     SYlarge_city "Ville, grande"
     SYlarge_exit_ns "Sortie sans service, grande"
     SYlarge_ramp_int "Ramp int, large"
@@ -597,7 +635,7 @@ array set TXT {
     SYntl_highway "Autoroute nationale"
     SYnull "(transparent)"
     SYnull_2 "(vide)"
-    SYoil_field "Puit de ptroile"
+    SYoil_field "Puits de ptrole"
     SYparachute "Parachute"
     SYpark "Parc"
     SYparking "Parking"
@@ -614,7 +652,7 @@ array set TXT {
     SYrestrooms "WC"
     SYRV_park "Camping car"
     SYscenic "Point de vue"
-    SYschool "Ecole"
+    SYschool "cole"
     SYseaplane "Base d'hydravion"
     SYshopping_cart "Commerces"
     SYshort_tower "Tour, courte"
@@ -634,9 +672,9 @@ array set TXT {
     SYswimming "Natation"
     SYtake_off "Dcollage"
     SYtall_tower "Tour, haute"
-    SYtheater "Thatre"
+    SYtheater "Thtre"
     SYtoll "Page"
-    SYtow_truck "Dpaneuse"
+    SYtow_truck "Dpanneuse"
     SYtraceback "Itinraire de retour"
     SYtracks "Traces"
     SYtrail_head "Dpart de piste"
@@ -646,7 +684,7 @@ array set TXT {
     SYultralight "ULM"
     SYus_highway "Autoroute nord amricaine"
     SYweight_station "Station de pesage"
-    SYwreck "Epave"
+    SYwreck "pave"
     SYzoo "Zoo"
     psvisible "Seul lment visible"
     DISPsymbol "Symbole uniquement"
@@ -656,14 +694,14 @@ array set TXT {
     DISPcomment "Commentaire uniquement"
     dispopt "Affichage"
     mapitems "Affichage des lments sur la carte"
-    nameIC "Icone"
+    nameIC "Icne"
     prod "Produit"
     WPCapac "Capacit en points d'itinraire"
-    ICCapac "Capacit en icones"
+    ICCapac "Capacit en icnes"
     RTCapac "Capacit en route"
     TRCapac "Capacit en traces"
     protcl "Protocole"
-    ICGraph "Graphique des icones"
+    ICGraph "Graphique des icnes"
     WPperRT "Point par route"
     notinGR "n'est pas dans le (sous-)groupe"
     onlyinGR "uniquement dans le (sous-)groupe"
@@ -708,12 +746,9 @@ array set TXT {
     lat0  "Latitude du centre"
     long0 "Longitude centre"
     lat1  "Latitude du 1er parallle"
-    lat2  "Latitude du 2eme parallle"
+    lat2  "Latitude du 2me parallle"
     latF  "Latitude de l'origine errone"
     longF "Longitude de l'origine errone"
-    gkklong0 "Longitude du centre"
-    kkjplong0 "Longitude du centre"
-    twglong0 "Longitude du centre"
     k0 "Facteur d'chelle"
     PRJUTM "UTM/UPS"
     PRJTM "Mercator Transverse"
@@ -736,9 +771,10 @@ array set TXT {
     never "Jamais"
     ask "Demander"
     always "Toujours"
-    stage "Etape"
-    label "Etiquette"
+    stage "tape"
+    label "tiquette"
     alt "Altitude"
+    optALTUNIT "Altitude"
     locate "Localiser"
     animation  Animation
     fast Rapide
@@ -747,7 +783,7 @@ array set TXT {
     pause Pause
     speed Vitesse
     centred "Centrage"
-    state "Etat"
+    state "tat"
     animinit "dbut / fin"
     animon "en cours"
     animpause "en pause"
@@ -775,13 +811,13 @@ array set TXT {
     posfixsimul simul
     restart "Redmarrage"
     mkTR "Faire une route"
-    PVTflds "# t lat long alt fix EPE EPH EPV vel_x vel_y vel_z CMG"
+    PVTflds "# t lat long alt fix EPE EPH EPV vel_x vel_y vel_z TRK"
     namePVTData "Journaliser les donnes"
     mkavgWP "Calcul du point moyen"
     move Dplacer
     define Dfinir
     open Ouvrir
-    defs "Definitions"
+    defs "Dfinitions"
     baseproj "Projection de base"
     abbrev "Nom court"
     grid Grille
@@ -802,16 +838,16 @@ array set TXT {
     atprevwp "Au point prcdent"
     prevwp "Point prcdent"
     firstwp "Premier point"
-    chglstrs "Editer la phase prcdente"
-    chgnxtrs "Editer la phase suivante"
+    chglstrs "diter la phase prcdente"
+    chgnxtrs "diter la phase suivante"
     contnend "Ajouter en fin"
     closemenu "Fermeture du menu"
-    ellpsd Ellipsoide
+    ellpsd Ellipsode
     datum Datum
     userdefs "Dfinitions de l'utilisateur"
-    edmap "Editer sur la carte"
+    edmap "diter sur la carte"
     actual "rel"
-    rtimelogintv "Interval de journalisation"
+    rtimelogintv "Intervalle de journalisation"
     inca "Inclure aprs"
     invert "Inverser"
     recwindow "Fentre du rcepteur"
@@ -827,14 +863,232 @@ array set TXT {
     optTRNUMBERINTVL "Intervalle pour la numrotation des points sur les traces"
     cluster "Groupement de points"
     mkclusters "Construction de groupements"
-    dlat "Interval de latitude"
-    dlong "Interval de longitude"
+    dlat "Intervalle de latitude"
+    dlong "Intervalle de longitude"
     collcntr "Dtection des centres..."
     compclstr "Calcul des groupements..."
     crtgclstrgrs "Cration des groupes..."
     PRJStereogr "Strographique"
-    PRJTWG "Grille de Taiwan"
+    PRJTWG "Grille tawanaise"
     chgdatum "Remplacer datum..."
+    optPRINTCMD "Commande d'impression"
+    optMAPFONTSIZE "Taille de police pour la carte"
+    print Impression
+    prevctr "Centre prcdent"
+    PRJSOM "Mercator Oblique Suisse"
+    PRJLV03 "Grille suisse LV03"
+    PRJIcG "Grille islandaise"
+    PRJRDG "Grille nerlandaise"
+    chgmfsize "Changement de taille pour la police de la carte"
+    printopt "Options d'impression"
+    numberid "Numro/Identifiant"
+    hiddendata "Donne masque"
+    YYYY/MM/DD  YYYY/MM/DD
+    cwpsdef "Dfinir les point de contrle"
+    nextTP "Prochain point de trace"
+    generate "Gnrer"
+    generateall "Gnrer tout"
+    optSERIALBAUD "Vitesse de transfert"
+    optDEFTRTWIDTH "Largeur des routes"
+    optDEFTTRWIDTH "Largeur des traces"
+    width "Largeur"
+    TRtoTR   "Simplification d'une trace"
+    TRlinedispl   "Affichage des rsultats"
+    obsTRsimpl "Trace rsultant d'une simplification"
+    simplTRto "Simplifier en"
+    exstglog "Journal existant"
+    contnsly "en continu"
+    animate "animer"
+    animabbrev "anim."
+    noanabbr "pas d'anim."
+    zelev "Echelle-Z"
+    xyelev "Echelle-XY"
+    notext "sans texte"
+    view "vue"
+    sideview "vue de cot"
+    persptv "Perspective"
+    SYgeocache "Gocache"
+    SYgeocache_fnd "Gocache trouve"
+    optMAPCOLOUR,trvtrk "Flche de trace"
+    optMAPCOLOUR,trvtrn "Flche "
+    optMAPCOLOUR,trvcts "Flche de course"
+    optMAPCOLOUR,trvcts2 "Seconde flche de course"
+    optMAPCOLOUR,trvvel_z "Flche haut/bas"
+    optMAPCOLOUR,trvwrnimportant "Avertissement important (nav)"
+    optMAPCOLOUR,trvwrnnormal "Avertissement (nav)"
+    optMAPCOLOUR,trvwrninfo "Information (nav)"
+    travel "Voyage"
+    notravel "Arrt du voyage"
+    optTRAVELFONTSIZE "Taille de la police d'affichage des voyages"
+    travdisplay "Configuration de l'affichage"
+    travchgdisplay "Changement pour l'affichage %s"
+    travdsetup "Configuration de l'affichage du voyage"
+    navMOB "Homme  la mer"
+    startnav "Navigation"
+    navWP "Aller au point"
+    goback "Retour"
+    follow "Suivre %s"
+    exactly "exactement"
+    fromnrst "depuis le plus prs"
+    inrvrs " l'envers"
+    forgetgoal "Oubli du but"
+    suspend "Suspension"
+    resume "Reprise"
+    TRVfix "Fix"
+    TRVhour "Heure"
+    TRVspeed "Vitesse"
+    TRVpos "Pos."
+    TRValt "Alt."
+    TRVtrk "Dir."
+    TRVnxtWP "Vers"
+    TRVprvWP "Depuis"
+    TRVete "ETE"
+    TRVeta "ETA"
+    TRVvmg "VMG"
+    TRVxtk "XTK"
+    TRVcts "Dir."
+    TRVtrn "Rot."
+    TRVvel_z "Vitesse vert."
+    TRVtrkcts "Trace, dir."
+    TRVdist "Dist"
+    TRVc_trkcts "Flche"
+    TRVc_trn "Flche"
+    TRVc_vel_z "Haut/Bas"
+    add "Ajout"
+    addlabelled "Ajout avec tiquette"
+    remove "Suppression"
+    mindist "Distance cible"
+    chginggoal "Changement vers le but suivant"
+    chggoalhlp "Changement depuis le but\ncourant jusqu'au prochain\nsur une route"
+    soon "bientt"
+    late "tard"
+    warnings "Avertissements"
+    dowarn "mission d'avertissements"
+    warnconf "Configuration d'avertissements"
+    priority "Priorit"
+    high "haute"
+    medium "mdiane"
+    low "basse"
+    warnprox "Distance au point <"
+    warnanchor "Distance au point >"
+    warnspeed "Vitesse >"
+    warntrn "Rotation (abs.) >"
+    warnvspeed "Vitesse verticale"
+    warnxtk "XTK (abs.)>"
+    fntsize "Taille de police"
+    trvhlpbox "Utiliser le bouton droit pour rordonnancer les lments ci-dessous"
+    trvhlpbxs "Utiliser le bouton droit pour rordonnancer les lments de la liste"
+    trvwarrv "Arrive  %s!"
+    trvwleave "Dpart de %s!"
+    trvwspeed "Vitesse > %s!"
+    trvwtrn "Rotation > %s!"
+    trvwvspeed "Vitesse verticale en dehors de [%s,%s]!"
+    trvwxtk "XTK > %s!"
+    trvwnolog "Journalisation en temps-rel arrte"
+    trvwnopos "Positions prcdentes indisponibles"
+    trvwuwps "La route a des points indfinis."
+    trvwchg "Aller au prochain %s"
+    TP "Point de trace"
+    drivesim "simulateur de conduite"
+    startfrom "Dpart depuis..."
+    outofctrl "Hors de contrle"
+    right "Droite"
+    left "Gauche"
+    straight "Tout droit"
+    rthlpdsim "Flches : conduite, changement de vitesse\nEspace : tout droit"
+    forgetGRcs "Oubli du groupe+els"
+    renres "NOUV"
+    chggoal "Changer pour le nouveau but"
+    Ghidden_class Classe
+    Ghidden_subclass "Sous-Classe"
+    Ghidden_lnk_ident "Identifiant de scne"
+    Ghidden_colour Couleur
+    Ghidden_attrs Attributs
+    Ghidden_depth Profondeur
+    Ghidden_state "tat"
+    Ghidden_country Pays
+    Ghidden_facility "Immeuble"
+    Ghidden_city Ville
+    Ghidden_addr Adresse
+    Ghidden_int_road "Croisement de rues"
+    Ghidden_dtyp "Affichage options et type"
+    Ghidden_ete "ETE"
+    Ghidden_display "Affichage?"
+    Ghidden_yes Oui
+    Ghidden_no Non
+    Ghidden_user "Utilisateur"
+    Ghidden_user_symbol "Utilisateur (symbole uniquement)"
+    Ghidden_non_user "Non utilisateur"
+    Ghidden_avn_airport "Aroport"
+    Ghidden_avn_inters "Avn intersection"
+    Ghidden_avn_NDB "NDB"
+    Ghidden_avn_VOR "VOR"
+    Ghidden_avn_airp_rway "Seuil de piste d'aroport"
+    Ghidden_avn_airp_int "Intersection aroport"
+    Ghidden_avn_airp_NDB "Aroport NDB"
+    Ghidden_map_pt "Point de carte"
+    Ghidden_map_area "Zone de carte"
+    Ghidden_map_int "Intersection de carte"
+    Ghidden_map_addr "Adresse de carte"
+    Ghidden_map_label "tiquette de carte"
+    Ghidden_map_line "Ligne de carte"
+    Ghidden_locked "Verrouill"
+    Ghidden_default "Dfaut"
+    Ghidden_black Noir
+    Ghidden_white Blanc
+    Ghidden_red Rouge
+    Ghidden_dark_red "Rouge fonc"
+    Ghidden_green Vert
+    Ghidden_dark_green "Vert fonc"
+    Ghidden_blue Bleu
+    Ghidden_dark_blue "Bleu fonc"
+    Ghidden_yellow Jaune
+    Ghidden_dark_yellow "Jaune fonc"
+    Ghidden_magenta Magenta
+    Ghidden_dark_magenta "Magenta fonc"
+    Ghidden_cyan Cyan
+    Ghidden_dark_cyan "Cyan fonc"
+    Ghidden_light_gray "Gris clair"
+    Ghidden_dark_gray "Gris fonc"
+    Ghidden_line Ligne
+    Ghidden_link Etape
+    Ghidden_net "Rseau"
+    Ghidden_direct Direct
+    Ghidden_snap Snap
+    PRJBMN "Grille BMN autrichienne"
+    PRJCTR "Carta Tecnica Reg (I)"
+    optDEFMAPPROJ "Projection de la carte"
+    optDEFMAPPFRMT "Coordonnes de la carte"
+    optMapGuideVersion "Version de MapGuide"    
+    undo "Dfaire"
+    UTMzone zone
+    tfwfile  "Ficher TFW"
+    ok Ok
+    GRA   Grades
+    newWPatdb "Nouveau WP   ..."
+    PRJLamb93 "Lambert 93"
+    PRJLambNTFe "NTF IIet"
+    PRJLambNTF "NTF"
+    NTFzone zone
+    opinprogr "Opration en cours"
+    working "En cours"
+    aborted "Arrt!"
+    errwarn "Erreur/Avertissement(s)!"
+    SYbiker "Cycliste"
+    SYbox_blue "Bote, bleue"
+    SYbox_green "Bote, verte"
+    SYbox_red "Bote, rouge"
+    SYflag_pin_blue "Epingle-Drapeau, bleue"
+    SYflag_pin_green "Epingle-Drapeau, verte"
+    SYflag_pin_red "Epingle-Drapeau, rouge"
+    SYhouse_2 "Maison 2"
+    SYpin_blue "Epingle, bleue"
+    SYpin_green "Epingle, verte"
+    SYpin_red "Epingle, rouge"
+    changegroupsymbol "Changer le symbole"
+    ozimapfile "Ficher Ozi Map"
+    info "Information"
+    climbrate "Vitesse verticale"
 }
 
     # the following definitions must be coherent with $TXT
@@ -842,6 +1096,7 @@ array set INVTXT {
     DMS   DMS
     DMM   DMM
     DDD   DDD
+    Grades   GRA
     UTM/UPS   UTM/UPS
     WP   WP
     RT   RT
