@@ -1,7 +1,7 @@
 #
 #  gpsman --- GPS Manager: a manager for GPS receiver data
 #
-#  Copyright (c) 2002 Miguel Filgueiras (mig@ncc.up.pt) / Universidade do Porto
+#  Copyright (c) 2004 Miguel Filgueiras (mig@ncc.up.pt) / Universidade do Porto
 #
 #    This program is free software; you can redistribute it and/or modify
 #      it under the terms of the GNU General Public License as published by
@@ -17,9 +17,9 @@
 #      along with this program.
 #
 #  File: langnl.tcl
-#  Last change:  1 February 2002
+#  Last change:  1 June 2004
 #  Dutch language file by Rob Buitenhuis (rob@buitenhs.demon.nl)
-#  last input from him inserted: 1 February 2002
+#  last input from him inserted: 1 June 2004
 #
 # 
 #  file langengl.tcl is consulted first; no need for duplicating entries here
@@ -41,11 +41,15 @@ set DLUNIT(STATMILE,subdist) ft
 set DLUNIT(STATMILE,speed) mph
 set DLUNIT(STATMILE,area) usml2
 
+set DLUNIT(M,dist) $DLUNIT(KM,subdist)
+set DLUNIT(FT,dist) $DLUNIT(STATMILE,subdist)
+
 set DTUNIT $DLUNIT($DISTUNIT,dist)
 set SPUNIT $DLUNIT($DISTUNIT,speed)
+set ALUNIT $DLUNIT($ALTUNIT,dist)
 
-set MESS(RTcomp) "#\tWP\t\t$DTUNIT\tgrd\tm"
-set MESS(TRcomp) "#\t$DTUNIT\t$DTUNIT\tm\th:m:s\t$SPUNIT\tgrd"
+set MESS(RTcomp) "#\tWP\t\t$DTUNIT\tgrd\t$ALUNIT"
+set MESS(TRcomp) "#\t$DTUNIT\t$DTUNIT\t$ALUNIT\th:m:s\t$SPUNIT\tgrd"
 set MESS(WPNearest) "WP\t\t$DTUNIT\tgrd"
 
 ## comments to Mess
@@ -57,7 +61,6 @@ set MESS(WPNearest) "WP\t\t$DTUNIT\tgrd"
 
 
 array set MESS {
-    notleap   "YEAR0 gedefinieerd als %d is geen schrikkeljaar"
     badscale   "Waarde niet geldig bij deze kaartschaal"
     oktoexit   "Ok om te stoppen (niet opgeslagen gegevens gaan verloren)"
     okclrmap   "Ok om de kaart te wissen"
@@ -78,7 +81,7 @@ array set MESS {
     unkndatum   "Onbekende datum"
     badcommdWP   "Niet geldig commando bij het laden van WP's; regel"
     notabsWP   "Niet geldige WP definitie; geen tabs, regel"
-    undefWP   "Verwijzing naar onbekend WP: %s; regel %d"
+    undefinedWP   "Verwijzing naar onbekend WP: %s"
     nofieldsWP   "Niet geldig WP, niet genoeg velden; regel"
     excfieldsWP  "Niet geldig WP, teveel velden; regel"
     badWPsRT   "RT met niet geldige waypoint-lijst; regel"
@@ -140,19 +143,15 @@ array set MESS {
     badserial "Kan seriele poort %s niet openen"
     nodata    "Geen %s's in ontvanger"
     badimage "Niet geldig beeld-bestand"
-    mapaskWPs "Kies a.u.b. %d WP's om op de kaart te plaatsen"
     mapadjust "Plaats a.u.b. WP's op de kaart; Ok om te stoppen"
     duplicate "%s al gekozen"
     clrcurrmap "Huidige kaart wissen?"
-    cantfix "%d WP's noodzakelijk om de kaart te justeren; laad of definieer eerst een paar WP's"
     mbkbaddatum "Geen of onbekende datum"
     mbkbadscale "Schaal mag niet negatief zijn"
     mbkbadat "Niet geldige argumenten"
     edityourrisk "Op eigen risico bewerken!"
     okclrbkmap   "Ok om de kaart-achtergrond te wissen"
     okclrbkim    "Ok om het beeld te wissen bij"
-    badWPfield "Foutief optioneel veld"
-    badWPattr "Onbekende optie-veld-naam"
     badSYMBOLcode "Niet geldige symbool-code"
     badDISPOPTcode "Niet geldige optie-code"
     goingdown "Instellingen worden opgeslagen; a.u.b. herstarten"
@@ -195,11 +194,9 @@ array set MESS {
     gotprots "Protocol-definities geladen"
     badprots "Niet geldige protocol-definities"
     defprots "Maak gebruik van de protocol-tabel"
-    nohidden "Verborgen gegevens overslaan?"
     badRS "Etappe van de route ligt buiten de definitie van de RT; regel"
     badWPsRSs "RT etappe voor het eerste of na het laatste WP; regel"
     windowdestr "Het window was gesloten!"
-    badhidden "Niet geldige weergave voor verborgen waarde"
     replname "Vervang \"%s\" door een naam met ten hoogste %d van de volgende karakters"
     badalt "Niet geldige waarde voor de hoogte"
     baddistunit "Niet geldige eenheid voor de kaartschaal in het instellingenbestand"
@@ -244,12 +241,49 @@ array set MESS {
     badinvproj "Benaderingsfout bij de inversie van de %s projectie"
     negdlatlong "Breedte/lengte mogen niet negatief zijn!"
     allundef "In de groep zijn geen definities voor de WP's inbegrepen"
-    badfloats "Floating-point conversie werkt niet goed, weet u zeker dat
-u verbinding wilt?"
+    badfloats "Floating-point conversie werkt niet goed, weet u zeker dat u verbinding wilt?"
+    noprintcmd "Geen afdruk commando; plaats er een in de opties"
+    cantexecasroot "GPSMan mag niet worden uitgevoerd als root"
+    badargtofunc "Foutief argument bij %s functie"
+    redefproj "Door gebruiker gedefinieerde %s projectie verwijdert een hiervoor gedefinieerde projectie met dezelfde afkorting; verander de definitie!"
+    badattr "Onbekende optionele veldnaam in %s : %s"
+    badattrval "Foutieve optionele veldwaarde in %s : %s"
+    couldntcd "Niet gelukt om naar directory %s te gaan"
+    shpext "Vereerde extensie %s; wilt u .shp, .shx, .dbf gebruiken?"
+    shpcntopen "Kan geen Shapefile bestanden maken of openen"
+    shpcntcrtfs "Kan geen Shapefile .dbf velden maken"
+    shpcntwrtfs "Kan geen Shapefile .dbf velden beschrijven"
+    shpoutmem "Memory is op!"
+    shpemptyfile "Leeg bestand"
+    shpwrongfile "Bestandstype ongeldig"
+    shplessdim "Dimensies in bestand minder dan vereist; doorgaan?"
+    shpbadWPinRT "%d-th WP met verkeerde coordinaten geweigerd in RT %s"
+    badGTMvers "Versie van GTrackMaker-bestand niet acceptabel"
+    badGTMfile "Verkeerd begin van GTrackMaker-bestand"
+    badGTMcounts "Negatieve telling(en) in GTrackMaker-bestand"
+    badGTMlat "Breedte buiten bereik in GTrackMaker-bestand"
+    badGTMlong "Lengte buiten bereik in GTrackMaker-bestand"
+    badGTMdatum "Verkeerde datum in GTrackMaker-bestand"
+    unobscmap "Fout, waarschijnlijk veroorzaakt door een window/icon over de kaart; opnieuw na een pauze?"
+    cantwrtimg "Fout tijdens schrijven van beeld naar bestand in %s formaat"
+    TRsimplres "TR als resultaat van vereenvoudiging gemaakt met naam %s"
+    cantsaveRTid "%d RT(s) niet opgeslagen: niet numerieke aanduiding"
+    badtrvconf "Corrupte configuratie; herstart met een lege"
+    drvsimoff "Rij-simulator: nog niet gestart!"
+    needWP "Rij-simulator: laad of definieer aub eerst wat WP's"
+    chgrecprot "Verander aub het ontvanger-protocol"
+    nohidden "Additionele geg. negeren?"
+    badhidden "Add. waarde heeft foutieve opmaak"
+    clrtrvlog "Log wissen?"
+    nmeainuse "Bezig met real-time log of het lezen van een ander NMEA bestand"
+    badfile "Fout gedurende het lezen van bestand"
+    RTnoWPname "WP in RT met alleen een naam wordt niet langer ondersteund"
+    distlarge "Afstand te groot!"
+    timeconsmg "Bewerking kost tijd: doorgaan?"
 }
 
-set TXT(RTcompflds) "# WP {$DTUNIT} graad m et. beschr."
-set TXT(TRcompflds) "TP {$DTUNIT} {$DTUNIT} m u:m:s {$SPUNIT} graad"
+set TXT(RTcompflds) "# WP {$DTUNIT} graad {$ALUNIT} et. beschr."
+set TXT(TRcompflds) "TP {$DTUNIT} {$DTUNIT} {$ALUNIT} u:m:s {$SPUNIT} graad"
 set TXT(starttoend) "Start: tot eind %s $DTUNIT;"
 set TXT(startmax) "max. %s $DTUNIT;"
 set TXT(WPnearflds) "WP {$DTUNIT} graad"
@@ -348,7 +382,6 @@ array set TXT {
     chophd   "Begin weglaten"
     choptl   "Eind weglaten"
     incb   "Invoegen voor"
-    mkRT   "Maak RT"
     date   Datum
     newdate   "Nieuwe datum voor volgend punt"
     endprTR   "Einde vorige track"
@@ -387,7 +420,7 @@ array set TXT {
     optDEFAULTDISPOPT "Standaard WP weergave-optie"
     opt_Data "Gegevens"
     optEQNAMEDATA "Gegevens met dezelfde naam"
-    optKEEPHIDDEN "Verborgen gegevens behouden"
+     optKEEPHIDDEN "Additionele geg. vasthouden"
     optDatum   Datum
     optTimeOffset   "Tijdsverschil"
     optACCFORMULAE "Precieze Formules"
@@ -442,7 +475,7 @@ array set TXT {
     optMAPCOLOUR,anim  "Kaart-animatie"
     optMAPCOLOUR,emptygrid  "Blanco afbeelding"
     optMAPCOLOUR,fullgrid   "Bestaand afbeelding"
-    opt_Files Bestanden
+    opt_Files "Seriele poort en bestanden"
     optDEFSPORT "Seriele poort"
     optPERMS   "Bestandsrechten"
     optPAPERSIZE "Papiergrootte"
@@ -471,7 +504,6 @@ array set TXT {
     joinGR   "Groep samenvoegen"
     TRtoRT   "Conversie van TR naar RT"
     TRRTnpoints   "Aantal punten" 
-    TRRTdispl   "RT nu weergeven"
     TRTRdispl   "TR nu weergeven"
     WP   WP
     RT   RT
@@ -709,9 +741,6 @@ array set TXT {
     projection "Projektie"
     lat0  "centrale breedte"
     long0 "centrale lengte"
-    gkklong0 "centrale lengte"
-    kkjplong0 "centrale lengte"
-    twglong0 "centrale lengte"
     k0 "Schaalfactor v.d. centrale meridiaan"
     PRJUTM "UTM/UPS"
     PRJTM  "Transv. Mercatorproj."
@@ -729,6 +758,7 @@ array set TXT {
     stage "Etappe"
     label "Beschrijving"
     alt "Hoogte"
+    optALTUNIT "Hoogte"
     locate "Lokaliseren"
     animation  Animatie
     fast Snel
@@ -773,6 +803,7 @@ array set TXT {
     latF  "Oorsprong van de breedte"
     longF "OOrsprong van de lengte"
     chgpfrmt "Positie-weergave wijzigen"
+    changegroupsymbol "Symbool wijzigen"
     closemenu "Menu sluiten"
     datum "Datum"
     bounds Begrenzing
@@ -821,6 +852,223 @@ array set TXT {
     crtgclstrgrs "Maken groepen..."
     PRJStereogr "Stereografische proj."
     chgdatum "Wijzig datum ..."
+    opt_Interf  "Gebruikers-interface"
+    optPRINTCMD "Afdruk commando"
+    optMAPFONTSIZE "Kaart-font grootte"
+    print "Druk af"
+    prevctr "Vorig centrum"
+    PRJSOM "Zwitsers Oblique Mercator"
+    PRJLV03 "Zwitsers LV03 Grid"
+    PRJIcG "IJslands Grid"
+    PRJRDG "Nederlands (RD) Grid"
+    chgmfsize "Verander kaart-font grootte"
+    printopt "Afdruk opties"
+    numberid "Getal/Aanduiding"
+    hiddendata "Afgeschermde gegevens"
+    YYYY/MM/DD  JJJJ/MM/DD
+    nextTP "Volgend TP"
+    generate Maak
+    generateall "Maak alles"
+    optSERIALBAUD "Baud Rate"
+    optDEFTRTWIDTH "RT lijn-dikte"
+    optDEFTTRWIDTH "TR lijn-dikte"
+    width Dikte
+    TRtoTR   "TR vereenvoudiging"
+    TRlinedispl   "Toon nu het resultaat"
+    obsTRsimpl "TR als resultaat van vereenvoudiging"
+    simplTRto "Vereenvoudig tot"
+    exstglog "Bestaande log"
+    contnsly "Continu"
+    animate "animeer"
+    animabbrev "anim."
+    noanabbr "niet anim."
+    zelev "Z-schaal"
+    xyelev "XY-schaal"
+    notext "geen tekst"
+    view "Aanzicht"
+    sideview "Aanzicht van opzij"
+    persptv "Perspectief"
+    SYgeocache "Geocache"
+    SYgeocache_fnd "Geocache gevonden"
+    optMAPCOLOUR,trvtrk "TRK pijl"
+    optMAPCOLOUR,trvtrn "TRN pijlen"
+    optMAPCOLOUR,trvcts "CTS pijl"
+    optMAPCOLOUR,trvcts2 "2e CTS pijl"
+    optMAPCOLOUR,trvvel_z "Op/neer pijl"
+    optMAPCOLOUR,trvwrnimportant "Belangrijke waarschuwing (nav)"
+    optMAPCOLOUR,trvwrnnormal "Waarschuwing (nav)"
+    optMAPCOLOUR,trvwrninfo "Informatie (nav)"
+    travel Verplaats
+    notravel "Stop verplaatsen"
+    optTRAVELFONTSIZE "Font-grootte verplaats-display"
+    travdisplay "Configureer display"
+    travchgdisplay "Ga naar display %s"
+    travdsetup "Configureer verplaatsings-display"
+    navMOB "MOB: Man Over Boord!"
+    startnav "Navigeer"
+    navWP "Ga naar WP"
+    goback "Go terug"
+    follow "Volg %s"
+    exactly "exact"
+    fromnrst "vanaf dichtsbijzijnde"
+    inrvrs "omgekeerd"
+    forgetgoal "vergeet het doel"
+    suspend "Onderbreek"
+    resume "Hervat"
+    TRVfix "Fix"
+    TRVhour "Tijd"
+    TRVspeed "Snelh"
+    TRVpos "Pos"
+    TRValt "hoogte"
+    TRVtrk "TRK"
+    TRVnxtWP "Naar"
+    TRVprvWP "Vanaf"
+    TRVete "ETE"
+    TRVeta "ETA"
+    TRVvmg "VMG"
+    TRVxtk "XTK"
+    TRVcts "CTS"
+    TRVtrn "TRN"
+    TRVvel_z "V snelh"
+    TRVtrkcts "TRK, CTS"
+    TRVdist "Afst"
+    TRVc_trkcts "TRK/CTS pijlen"
+    TRVc_trn "TRN pijlen"
+    TRVc_vel_z "Op/neer pijl"
+    add "Toevoegen"
+    addlabelled "Voeg toe met label"
+    remove "Verwijder"
+    mindist "Afstand tot aankomst"
+    chginggoal "Ga naar volgend doel"
+    chggoalhlp "Gaande van\nhuidig naar volgenddoel\nterwijl RT/TR gevolgd wordt"
+    soon binnenkort
+    late later
+    warnings "Waarschuwingen"
+    dowarn "Geef waarschuwingen"
+    warnconf "Configureer waarschuwingen"
+    priority Prioriteit
+    high hoog
+    medium middel
+    low laag
+    warnprox "Afstand tot WP <"
+    warnanchor "Afstand tot WP >"
+    warnspeed "Snelheid >"
+    warntrn "TRN (abs)>"
+    warnvspeed "Verticale snelheid"
+    warnxtk "XTK (abs)>"
+    fntsize "Font-grootte"
+    trvhlpbox "Gebruik rechter-button om onderstaande elementen te herschikken"
+    trvhlpbxs "Gebuik rechter-button om lijst-elementen te herschikken"
+    trvwarrv "Aankomst bij %s!"
+    trvwleave "Vertrek van %s!"
+    trvwspeed "Snelheid > %s!"
+    trvwtrn "TRN > %s!"
+    trvwvspeed "Vert snelheid niet in [%s,%s]!"
+    trvwxtk "XTK > %s!"
+    trvwnolog "Real-time logging is uit!"
+    trvwnopos "Vorige posities niet beschikbaar"
+    trvwuwps "RT heeft ongedefinieerd(e) WP(s)"
+    trvwchg "Ga nu naar %s"
+    TP TP
+    drivesim "rij-simulator"
+    startfrom "Start vanaf..."
+    outofctrl "Geen controle meer!"
+    right Rechts
+    left Links
+    straight Rechtuit
+    rthlpdsim "Pijltjes-toetsen: sturen, verander snelheid\nSpatiebalk: rechtuit"
+    renres "HERNOEMD"
+    chggoal "Volgend doel instellen"
+    Ghidden_class Klasse
+    Ghidden_subclass Subklasse
+    Ghidden_lnk_ident "Traject id"
+    Ghidden_colour Kleur
+    Ghidden_attrs Attributen
+    Ghidden_depth Diepte
+    Ghidden_state Staat
+    Ghidden_country Land
+    Ghidden_facility Faciliteit
+    Ghidden_city Stad
+    Ghidden_addr Addres
+    Ghidden_int_road "Kruisende weg"
+    Ghidden_dtyp "Display opt+type"
+    Ghidden_ete "ETE"
+    Ghidden_display "Display?"
+    Ghidden_yes Ja
+    Ghidden_no Nee
+    Ghidden_user "Gebruiker"
+    Ghidden_user_symbol "Gebruiker (alleen symbool)"
+    Ghidden_non_user "Niet-gebruiker"
+    Ghidden_avn_airport "Vliegveld"
+    Ghidden_avn_inters "Kruispunt luchtwegen"
+    Ghidden_avn_NDB "NDB"
+    Ghidden_avn_VOR "VOR"
+    Ghidden_avn_airp_rway "Drempel landingsbaan"
+    Ghidden_avn_airp_int "Kruispunt vliegveld"
+    Ghidden_avn_airp_NDB "Vliegveld NDB"
+    Ghidden_map_pt "Kaart punt"
+    Ghidden_map_area "Kaart gebied"
+    Ghidden_map_int "Kaart kruispunt"
+    Ghidden_map_addr "Kaart addres"
+    Ghidden_map_label "Kaart label"
+    Ghidden_map_line "Kaart lijn"
+    Ghidden_locked Vastgezet
+    Ghidden_default "Verstek"
+    Ghidden_black Zwart
+    Ghidden_white Wit
+    Ghidden_red Rood
+    Ghidden_dark_red "Donkerrood"
+    Ghidden_green Groen
+    Ghidden_dark_green "Donkergroen"
+    Ghidden_blue Blauw
+    Ghidden_dark_blue "Donkerblauw"
+    Ghidden_yellow Geel
+    Ghidden_dark_yellow "Donkergeel"
+    Ghidden_magenta Magenta
+    Ghidden_dark_magenta "Donkermagenta"
+    Ghidden_cyan Cyaan
+    Ghidden_dark_cyan "Donkercyaan"
+    Ghidden_light_gray "Lichtgrijs"
+    Ghidden_dark_gray "Donkergrijs"
+    Ghidden_line Lijn
+    Ghidden_link Traject
+    Ghidden_net Rooster
+    Ghidden_direct Direct
+    Ghidden_snap Klik
+    cwpsdef "Alsnog te def. referentie-WP's"
+    PRJBMN "Oostenrijks BMN Grid"
+    PRJCTR "Carta Tecnica Reg (I)"
+    optDEFMAPPROJ "Kaartprojectie"
+    optDEFMAPPFRMT "Kaartcoordinaten"
+    optMapGuideVersion "MapGuide versie"
+    undo "Ongedaan maken"
+    UTMzone zone
+    tfwfile  "TFW-bestand"
+    ok Ok
+    GRA   Gon
+    newWPatdb "Nieuw WP bij..."
+    PRJLamb93 "Lambert 93"
+    PRJLambNTFe "NTF IIet"
+    PRJLambNTF "NTF"
+    NTFzone zone
+    opinprogr "Bezig met bewerking"
+    working "Bezig"
+    aborted "Afgebroken!"
+    errwarn "Fout/waarschuwing(en)!"
+    SYbiker "Fietser"
+    SYbox_blue "Kubus, blauw"
+    SYbox_green "Kubus, groen"
+    SYbox_red "Kubus, rood"
+    SYflag_pin_blue "Vlaggetje, blauw"
+    SYflag_pin_green "Vlaggetje, groen"
+    SYflag_pin_red "Vlaggetje, rood"
+    SYhouse_2 "House 2"
+    SYpin_blue "Speld, blauw"
+    SYpin_green "Speld, groen"
+    SYpin_red "Speld, rood"
+    ozimapfile "Ozi Map-bestand"
+    info "Informatie"
+    climbrate "Klimsnelheid"
 }
 
     # the following definitions must be coherent with $TXT
@@ -828,10 +1076,10 @@ array set INVTXT {
     DMS   DMS
     DMM   DMM
     DDD   DDD
+    Gon   GRA
     UTM/UPS   UTM/UPS
     WP   WP
     RT   RT
     TR   TR
     GR   GR
 }
-
