@@ -1,7 +1,7 @@
 #
 #  gpsman --- GPS Manager: a manager for GPS receiver data
 #
-#  Copyright (c) 2002 Miguel Filgueiras (mig@ncc.up.pt) / Universidade do Porto
+#  Copyright (c) 2004 Miguel Filgueiras (mig@ncc.up.pt) / Universidade do Porto
 #
 #    This program is free software; you can redistribute it and/or modify
 #      it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
 #      along with this program.
 #
 #  File: options.tcl
-#  Last change:  1 February 2002
+#  Last change:  18 January 2004
 #
 
 # when inserting new data here, define TXT(opt*)
@@ -29,6 +29,7 @@
 #      nat        natural number (=nonnegative integer); as an entry
 #      float      any number; as an entry
 #      any        any non-empty string; as an entry
+#      any_empty  any string or empty; as an entry
 #      colour     a special dialog is used for selection
 #      perms      file permissions; a special dialog is used for selection
 #      oneof      as a radiobutton; one must define $OPTVALS($i) as a
@@ -65,6 +66,9 @@
 #      whose elements will be set to selected values (in case of array)
 #      - arrays and groups can only appear at top level
 
+# maximum number of widgets per column
+set OPTMAXHEIGHT 10
+
 set OPTSTRUCT {   GPSREC _GPSRecConf _Formats _sep
                   _Data _sep
 	          _Interf _Geom COLOUR _MapGeom MAPCOLOUR _sep 
@@ -93,9 +97,10 @@ set OPTMENUPROC(GPSREC) FillRecModelsMenu
 # the _GPSRecConf description may be changed by proc RecModelChange
 #  in file recmodels.tcl when $GPSREC changes
 set OPTTYPE(_GPSRecConf) group
-set OPTGRPL(_GPSRecConf) {NAMELENGTH COMMENTLENGTH MAXWPOINTS MAXROUTES
-                      MAXWPINROUTE MAXTPOINTS CREATIONDATE NOLOWERCASE
-                      DEFAULTSYMBOL DEFAULTDISPOPT}
+set OPTGRPL(_GPSRecConf) {ACCEPTALLCHARS NAMELENGTH COMMENTLENGTH MAXWPOINTS
+                      MAXROUTES MAXWPINROUTE MAXTPOINTS CREATIONDATE
+                      NOLOWERCASE DEFAULTSYMBOL DEFAULTDISPOPT}
+set OPTTYPE(ACCEPTALLCHARS) boolean
 set OPTTYPE(NAMELENGTH) nat
 set OPTTYPE(COMMENTLENGTH) nat
 set OPTTYPE(MAXWPOINTS) nat
@@ -123,8 +128,9 @@ set OPTTYPE(KEEPHIDDEN) oneof
 set OPTVALS(KEEPHIDDEN) {never ask always}
 
 set OPTTYPE(_Formats) group
-set OPTGRPL(_Formats) {Datum TimeOffset DISTUNIT PositionFormat DateFormat
-                       ACCFORMULAE ASKPROJPARAMS}
+set OPTGRPL(_Formats) {Datum TimeOffset DISTUNIT ALTUNIT PositionFormat
+                       DateFormat DEFMAPPROJ DEFMAPPFRMT ACCFORMULAE
+                       ASKPROJPARAMS}
 
 set OPTTYPE(Datum) menu
 set OPTMENUPROC(Datum) FillDatumMenu
@@ -132,13 +138,26 @@ set OPTMENUPROC(Datum) FillDatumMenu
 set OPTTYPE(TimeOffset) float
 
 set OPTTYPE(DISTUNIT) oneof
-set OPTVALS(DISTUNIT) "KM NAUTMILE STATMILE"
+set OPTVALS(DISTUNIT) {KM NAUTMILE STATMILE}
+
+set OPTTYPE(ALTUNIT) oneof
+set OPTVALS(ALTUNIT) {M FT}
 
 set OPTTYPE(PositionFormat) fixedmenu
 set OPTMENUCONTS(PositionFormat) $PFORMATS
 
-set OPTTYPE(DateFormat) oneof
-set OPTVALS(DateFormat) "YYYYMMDD YYYY-MM-DD MMDDYYYY DDMMMYYYY"
+set OPTTYPE(DateFormat) fixedtextmenu
+set OPTMENUCONTS(DateFormat) [lsort -dictionary [array names DATEW]]
+set OPTMENUNAMES(DateFormat) TXT
+set OPTMENUPREFIX(DateFormat) {}
+
+set OPTTYPE(DEFMAPPROJ) fixedtextmenu
+set OPTMENUCONTS(DEFMAPPROJ) $MAPKNOWNPROJS
+set OPTMENUNAMES(DEFMAPPROJ) TXT
+set OPTMENUPREFIX(DEFMAPPROJ) PRJ
+
+set OPTTYPE(DEFMAPPFRMT) fixedmenu
+set OPTMENUCONTS(DEFMAPPFRMT) $PFORMATS
 
 set OPTTYPE(ACCFORMULAE) boolean
 
@@ -147,7 +166,9 @@ set OPTTYPE(ASKPROJPARAMS) boolean
 set OPTTYPE(_MapGeom) group
 set OPTGRPL(_MapGeom) {MAPWIDTH MAPHEIGHT _sep
                        MAPSCLENGTH MAPSCALE _sep
-                       DPOSRTMAP}
+                       DPOSRTMAP _sep
+                       MAPFONTSIZE TRAVELFONTSIZE DEFTRTWIDTH DEFTTRWIDTH
+                       DEFTLNWIDTH}
 
 set OPTTYPE(_Geom) group
 set OPTGRPL(_Geom) {MAXMENUITEMS LISTWIDTH LISTHEIGHT _sep
@@ -170,6 +191,16 @@ set OPTTYPE(EPOSY) nat
 set OPTTYPE(DPOSX) nat
 set OPTTYPE(DPOSY) nat
 set OPTTYPE(DPOSRTMAP) float
+set OPTTYPE(MAPFONTSIZE) fixedmenu
+set OPTMENUCONTS(MAPFONTSIZE) $MAPFTSIZES
+set OPTTYPE(TRAVELFONTSIZE) fixedmenu
+set OPTMENUCONTS(TRAVELFONTSIZE) $MAPFTSIZES
+set OPTTYPE(DEFTRTWIDTH) fixedmenu
+set OPTMENUCONTS(DEFTRTWIDTH) {1 2 3 4 5 6 7 8}
+set OPTTYPE(DEFTTRWIDTH) fixedmenu
+set OPTMENUCONTS(DEFTTRWIDTH) {1 2 3 4 5 6 7 8}
+set OPTTYPE(DEFTLNWIDTH) fixedmenu
+set OPTMENUCONTS(DEFTLNWIDTH) {1 2 3 4 5 6 7 8}
 set OPTTYPE(LISTWIDTH) nat
 set OPTTYPE(LISTHEIGHT) nat
 
@@ -180,22 +211,28 @@ set OPTELS(COLOUR) {fg bg messbg confbg selbg dialbg offline online check
 
 set OPTTYPE(MAPCOLOUR) array
 set OPTELTYPE(MAPCOLOUR) colour
-set OPTELS(MAPCOLOUR) {mapsel WP RT mkRT TR TP mapleg anim emptygrid fullgrid}
+set OPTELS(MAPCOLOUR) {mapsel WP RT mkRT TR TP LN mapleg anim emptygrid
+                       fullgrid trvtrk trvtrn trvcts trvcts2 trvvel_z
+                       trvwrnimportant trvwrnnormal trvwrninfo}
 
 set OPTTYPE(_Files) group
-if { "$tcl_platform(platform)" == "unix" } {
-    set OPTGRPL(_Files) {DEFSPORT _sep SAVESTATE DELSTATE _sep PERMS PAPERSIZE}
+if { $UNIX } {
+    set OPTGRPL(_Files) {DEFSPORT _sep}
     set OPTTYPE(DEFSPORT) any
-} else {
-    set OPTGRPL(_Files) {SAVESTATE DELSTATE _sep PERMS PAPERSIZE}
-}
+} else { set OPTGRPL(_Files) "" }
+lappend OPTGRPL(_Files) SAVESTATE DELSTATE _sep PERMS PRINTCMD PAPERSIZE \
+	_sep MapGuideVersion
+
 set OPTTYPE(SAVESTATE) oneof
 set OPTVALS(SAVESTATE) {never ask always}
 set OPTTYPE(DELSTATE) oneof
 set OPTVALS(DELSTATE) {never ask always}
 set OPTTYPE(PERMS) perms
+set OPTTYPE(PRINTCMD) any_empty
 set OPTTYPE(PAPERSIZE) fixedmenu
 set OPTMENUCONTS(PAPERSIZE) [array names PAGEWIDTH]
+set OPTTYPE(MapGuideVersion) fixedmenu
+set OPTMENUCONTS(MapGuideVersion) {2002 03/04}
 
 set OPTTYPE(_sep) sep
 
@@ -203,7 +240,7 @@ proc OutDatedOptions {} {
     # check if options read from preferences file are outdated
     global OPTFILEVERSION VERSION MESS GPSREC MWINDOWSCONF
 
-    if { [catch "set OPTFILEVERSION"] } {
+    if { [catch {set OPTFILEVERSION}] } {
 	# this is a pre-4.0 preferences file
 	AboutInfo ""
 	GMMessage $MESS(outdatedprefs)
@@ -211,11 +248,11 @@ proc OutDatedOptions {} {
     }
     set r [string compare $OPTFILEVERSION $VERSION]
     # correct outdated values
-    if { [llength $GPSREC]>1 && "[lindex $GPSREC 0]" == "Garmin" } {
+    if { [llength $GPSREC]>1 && [lindex $GPSREC 0] == "Garmin" } {
 	# no need for Garmin receiver model after version 4.0.1
 	set GPSREC Garmin ; set r 1
     }
-    if { "$MWINDOWSCONF" == "single" } {
+    if { $MWINDOWSCONF == "single" } {
 	# no longer supported after 5.2
 	set MWINDOWSCONF map ; set r 1
     }
@@ -231,7 +268,7 @@ proc SetOptions {} {
     # create modal dialog for setting user options
     # return 1 on success, 0 on failure
     global USEROPTIONS OPTSTRUCT OPTTYPE MESS TXT DPOSX DPOSY COLOUR VERSION \
-	    TempOpts OptOldMain OptOldSub
+	    TempOpts OptOldMain OptOldSub OPTMAXHEIGHT
 
     # window name used elsewhere
     set w .opts
@@ -239,17 +276,29 @@ proc SetOptions {} {
 
     toplevel $w
     wm protocol $w WM_DELETE_WINDOW { set TempOpts cnc ; set waitopts 0 }
-    wm title $w "GPS Manager: $TXT(options)"
+    wm title $w "$TXT(options)/GPS Manager"
     wm transient $w .
     wm geometry $w +$DPOSX+$DPOSY
     bind $w <Key-Return> { set TempOpts ok ; set waitopts 0 }
 
-    frame $w.fr -borderwidth 5 -bg $COLOUR(dialbg)
+    frame $w.fr -borderwidth 5 -bg $COLOUR(messbg)
 
-    set i 0 ; set es ""
+    set i 0 ; set es "" ; set col 0
+    if { [set n [llength $OPTSTRUCT]] < $OPTMAXHEIGHT } {
+	set row -1 ; set drow 0 ; set maxrow 1000
+    } else {
+	set row 0 ; set drow 1
+	if { [set z [expr int($n/$OPTMAXHEIGHT)]] != 1.0*$n/$OPTMAXHEIGHT } {
+	    incr z
+	}
+	if { [set maxrow [expr int($n/$z)]] != $n/$z } { incr maxrow }
+    }
     foreach v $OPTSTRUCT {
-	set es [ShowOption $v $v $v $OPTTYPE($v) $w.fr.f$i $es Main]
+	set es [ShowOption $v $v $v $OPTTYPE($v) $w.fr.f$i $es Main $row $col]
 	incr i
+	if { [incr row $drow] > $maxrow } {
+	    set row 0 ; incr col
+	}
     }
 
     frame $w.fr.bs
@@ -258,18 +307,24 @@ proc SetOptions {} {
 	    -command { set TempOpts cnc ; set waitopts 0 }
 
     pack $w.fr.bs.ok $w.fr.bs.cnc -side left -pady 5
-    pack $w.fr.bs $w.fr -side top
+    if { $row == -1 } {
+	pack $w.fr.bs $w.fr -side top
+    } else {
+	grid $w.fr.bs -row [incr maxrow] -column 0 -columnspan [incr col] \
+		-pady 5
+	pack $w.fr -side top
+    }
 
     update idletasks
+    set gs [grab current]
     grab $w
-    # RaiseWindow $w
+    # cannot use RaiseWindow because of the menus
     while 1 {
 	tkwait variable waitopts
 
 	switch $TempOpts {
 	    ""  { }
 	    cnc { 
-		destroy $w
 		foreach ref [array names OptOldMain] {
 		    ChangeOption $ref $OptOldMain($ref)
 		}
@@ -279,19 +334,18 @@ proc SetOptions {} {
 			unset OptOldSub($ref)
                     }
 		}
-		update idletasks
-		return 0
-	        }
-	    ok  {
+		set res 0
+		break
+	    }
+	    ok {
 		set ok 1
 		foreach e $es {
 		                 # these entries cannot be for array elements
 		    set v [lindex $e 1]
 		    global $v
 		    switch $OPTTYPE($v) {
-			nat -
-			float -
-			any {
+			nat -  float -  any -
+			any_empty {
 			    set val [[lindex $e 0] get]
 			    if { [WrongValue $OPTTYPE($v) $val] } {
 				GMMessage "$TXT(wrgval) $TXT(opt$v)"
@@ -302,11 +356,10 @@ proc SetOptions {} {
 		    }
 		}
 		if { $ok } {
-		    if { [catch "set f [open $USEROPTIONS w]"] } {
+		    if { [catch {set f [open $USEROPTIONS w]}] } {
 			GMMessage $MESS(cantwrtopt)
-			destroy $w
-			update idletasks
-			return 0
+			set res 0
+			break
 		    }
 		    puts $f ""
 		    puts $f "# $MESS(written) GPSMan [NowTZ]"
@@ -316,16 +369,18 @@ proc SetOptions {} {
 		    puts $f ""
 		    foreach v $OPTSTRUCT { GenOption $f $v }
 		    close $f
-		    destroy $w
-		    update idletasks
-		    return 1
+		    set res 1
+		    break
 		}
 	    }
 	}
     }
+    DestroyRGrabs $w $gs
+    update idletasks
+    return $res
 }
 
-proc ShowOption {v ref val type vf es lv} {
+proc ShowOption {v ref val type vf es lv row col} {
     # create widgets for an identifier in options list
     #  $v is identifier (normally a variable)
     #  $ref is a reference used to keep the initial value of the option
@@ -337,6 +392,8 @@ proc ShowOption {v ref val type vf es lv} {
     #  $es is list with a pair for each created entry; the pair has the
     #    path for the entry and $ref
     #  $lv recursion level in {Main Sub New}
+    #  $row is -1 if frame $vf is to be packed; otherwise frame should be
+    #     grided at row $row and column $col
     global OPTVALS OPTMENUPROC OPTMENUCONTS OPTMENUNAMES OPTMENUPREFIX \
 	    COLOUR TXT MAXMENUITEMS OptOld$lv OptSubMany OptMenuVar \
 	    OptMenuText OptPerms
@@ -352,9 +409,8 @@ proc ShowOption {v ref val type vf es lv} {
 	    if { [set $val] } { $vf.f select }
 	    pack $vf.f -anchor w
 	}
-	nat -
-	float -
-	any {
+	nat -  float -  any -
+	any_empty {
 	    global $v
 	    set OptOld[set lv]($ref) [set $val]
 	    label $vf.l -text $TXT(opt$ref)
@@ -373,7 +429,7 @@ proc ShowOption {v ref val type vf es lv} {
 	    foreach vl $OPTVALS($v) {
 		radiobutton $vf.r$vl -text $TXT($vl) -variable $val \
 			-value $vl -anchor w -selectcolor $COLOUR(check)
-		if { "[set $val]" == "$vl" } {
+		if { [set $val] == $vl } {
 		    $vf.r$vl invoke
 		}
 		pack $vf.r$vl -side left -padx 2
@@ -382,7 +438,8 @@ proc ShowOption {v ref val type vf es lv} {
 	menu {
 	    global $v
 	    set OptOld[set lv]($ref) [set $val]
-	    menubutton $vf.mb -text $TXT(opt$ref) -menu $vf.mb.m$ref
+	    menubutton $vf.mb -text $TXT(opt$ref) -relief raised \
+		    -direction below -menu $vf.mb.m$ref
 	    menu $vf.mb.m$ref
 	    set OptMenuVar($vf.mb.m$ref) $ref
 	    $OPTMENUPROC($v) $vf.mb.m$ref ChangeMenuOption
@@ -392,7 +449,8 @@ proc ShowOption {v ref val type vf es lv} {
 	textmenu {
 	    global $v $OPTMENUNAMES($v)
 	    set OptOld[set lv]($ref) [set $val]
-	    menubutton $vf.mb -text $TXT(opt$ref) -menu $vf.mb.m$ref
+	    menubutton $vf.mb -text $TXT(opt$ref) -relief raised \
+		    -direction below -menu $vf.mb.m$ref
 	    set mw $vf.mb.m$ref
 	    menu $mw
 	    set OptMenuVar($mw) $ref
@@ -407,7 +465,8 @@ proc ShowOption {v ref val type vf es lv} {
 	fixedmenu {
 	    global $v
 	    set OptOld[set lv]($ref) [set $val]
-	    menubutton $vf.mb -text $TXT(opt$ref) -menu $vf.mb.m$ref
+	    menubutton $vf.mb -text $TXT(opt$ref) -relief raised \
+		    -direction below -menu $vf.mb.m$ref
 	    menu $vf.mb.m$ref
 	    set OptMenuVar($vf.mb.m$ref) $ref
 	    set mw $vf.mb.m$ref ; set n 0 ; set m 0
@@ -427,7 +486,8 @@ proc ShowOption {v ref val type vf es lv} {
 	fixedtextmenu {
 	    global $v $OPTMENUNAMES($v)
 	    set OptOld[set lv]($ref) [set $val]
-	    menubutton $vf.mb -text $TXT(opt$ref) -menu $vf.mb.m$ref
+	    menubutton $vf.mb -text $TXT(opt$ref) -relief raised \
+		    -direction below -menu $vf.mb.m$ref
 	    set mw $vf.mb.m$ref
 	    menu $mw
 	    set OptMenuVar($mw) $ref
@@ -474,12 +534,12 @@ proc ShowOption {v ref val type vf es lv} {
 	    global $v
 	    set OptOld[set lv]($ref) [set $val]
 	    button $vf.b -text $TXT(opt$ref) -relief raised \
-		    -command "ChooseColour $v $ref $val $vf"
+		    -command "ChooseColour $v $val $vf .opts"
 	    label $vf.bc -relief groove -background [set $val] -width 2
 	    pack $vf.b $vf.bc -side left
 	}
 	group {
-	    if { "$lv" != "Main" } {
+	    if { $lv != "Main" } {
 		GMMessage "Bad option type for $v: groups only at top level"
 	    } else {
 		set OptSubMany($v) 0
@@ -490,7 +550,7 @@ proc ShowOption {v ref val type vf es lv} {
 	    }
 	}
 	array {
-	    if { "$lv" != "Main" } {
+	    if { $lv != "Main" } {
 		GMMessage "Bad option type for $v: arrays only at top level"
 	    } else {
 		set OptSubMany($v) 0
@@ -506,83 +566,96 @@ proc ShowOption {v ref val type vf es lv} {
 	    pack $vf.sep
 	}
     }
-    pack $vf -side top -pady 3 -anchor w -fill x
+    if { $row == -1 } {
+	pack $vf -side top -pady 3 -anchor w -fill x
+    } else { grid $vf -row $row -column $col -pady 3 -padx 3 -sticky we }
     return $es
 }
 
 proc ShowMoreOptions {g} {
     # create sub-window for setting options in the group $g
     global OPTGRPL OPTTYPE MESS TXT DPOSX DPOSY COLOUR TempMOpts OptOldSub \
-	    OptOldNew OptOldMain OptSubMany
+	    OptOldNew OptOldMain OptSubMany OPTMAXHEIGHT
 
     set w .mopts
     if { [winfo exists $w] } { Raise $w ; bell ; return }
 
     toplevel $w
-    wm protocol $w WM_DELETE_WINDOW { set TempMOpts cnc ; set waitmopts 0 }
-    wm title $w "GPS Manager: $TXT(options)"
+    wm protocol $w WM_DELETE_WINDOW { set TempMOpts cnc }
+    wm title $w "$TXT(options)/GPS Manager"
     wm transient $w .opts
     wm geometry $w +$DPOSX+$DPOSY
-    bind $w <Key-Return> { set TempMOpts ok ; set waitmopts 0 }
+    bind $w <Key-Return> { set TempMOpts ok }
 
     frame $w.fr -relief flat -borderwidth 5 -bg $COLOUR(dialbg)
 
     if { $OptSubMany($g) } { set lv New } else {
 	set lv Sub
 	foreach v $OPTGRPL($g) {
-	    if { "$OPTTYPE($v)" != "sep" } {
+	    if { $OPTTYPE($v) != "sep" } {
 		global $v
 		set OptOldMain($v) [set $v]
 	    }
 	}
     }
     incr OptSubMany($g)
-    set i 0 ; set es ""
+    set i 0 ; set es "" ; set col 0
+    if { [set n [llength $OPTGRPL($g)]] < $OPTMAXHEIGHT } {
+	set row -1 ; set drow 0 ; set maxrow 1000
+    } else {
+	set row 0 ; set drow 1
+	if { [set z [expr int($n/$OPTMAXHEIGHT)]] != 1.0*$n/$OPTMAXHEIGHT } {
+	    incr z
+	}
+	if { [set maxrow [expr int($n/$z)]] != $n/$z } { incr maxrow }
+    }
     foreach v $OPTGRPL($g) {
-	set es [ShowOption $v $v $v $OPTTYPE($v) $w.fr.f$i $es $lv]
+	set es [ShowOption $v $v $v $OPTTYPE($v) $w.fr.f$i $es $lv $row $col]
 	incr i
+	if { [incr row $drow] > $maxrow } {
+	    set row 0 ; incr col
+	}
     }
 
     frame $w.fr.bs
-    button $w.fr.bs.ok -text Ok -command { set TempMOpts ok ; set waitmopts 0 }
-    button $w.fr.bs.cnc -text $TXT(cancel) \
-	    -command { set TempMOpts cnc ; set waitmopts 0 }
+    button $w.fr.bs.ok -text Ok -command { set TempMOpts ok }
+    button $w.fr.bs.cnc -text $TXT(cancel) -command { set TempMOpts cnc }
 
     pack $w.fr.bs.ok $w.fr.bs.cnc -side left -pady 5
-    pack $w.fr.bs $w.fr -side top
+    if { $row == -1 } {
+	pack $w.fr.bs $w.fr -side top
+    } else {
+	grid $w.fr.bs -row [incr maxrow] -column 0 -columnspan [incr col] \
+		-pady 5
+	pack $w.fr -side top
+    }
 
-    set pw [grab current]
     update idletasks
+    set gs [grab current]
     grab $w
-    # RaiseWindow $w
+    # cannot use RaiseWindow
     while 1 {
-	tkwait variable waitmopts
+	tkwait variable TempMOpts
 
 	switch $TempMOpts {
 	    ""  { }
 	    cnc { 
-		destroy $w
-		if { "$pw" != "" } {
-		    grab [lindex $pw 0]
-		}
 		foreach v [array names OptOld$lv] {
 		                # these cannot be arrays
 		    global $v
 		    set $v [set OptOld[set lv]($v)] ; unset OptOld[set lv]($v)
 		}
-		update idletasks
-		return
-	        }
-	    ok  {
+		break
+	    }
+	    ok {
 		set ok 1
 		foreach e $es {
 		                # these entries cannot be for array elements
 		    set v [lindex $e 1]
 		    global $v
 		    switch $OPTTYPE($v) {
-			nat -
-			float -
-			any {
+			nat -  float -  any -
+			any_empty {
 			    set val [[lindex $e 0] get]
 			    if { [WrongValue $OPTTYPE($v) $val] } {
 				GMMessage "$TXT(wrgval) $TXT(opt$v)"
@@ -592,33 +665,29 @@ proc ShowMoreOptions {g} {
 			}
 		    }
 		}
-		if { $ok } {
-		    destroy $w
-		    if { "$pw" != "" } {
-			grab [lindex $pw 0]
-		    }
-		    update idletasks
-		    return
-		}
+		if { $ok } { break }
 	    }
 	}
     }
+    DestroyRGrabs $w $gs
+    update idletasks
+    return
 }
 
 proc ShowOptionsArray {a} {
     # create sub-window for setting options in options array $a
     global OPTELTYPE OPTELS MESS TXT DPOSX DPOSY COLOUR TempAOpts OptOldSub \
-	    OptOldNew OptOldMain OptSubMany $a
+	    OptOldNew OptOldMain OptSubMany $a OPTMAXHEIGHT
 
     set w .aopts
     if { [winfo exists $w] } { Raise $w ; bell ; return }
 
     toplevel $w
-    wm protocol $w WM_DELETE_WINDOW { set TempAOpts cnc ; set waitaopts 0 }
-    wm title $w "GPS Manager: $TXT(options)"
+    wm protocol $w WM_DELETE_WINDOW { set TempAOpts cnc }
+    wm title $w "$TXT(options)/GPS Manager"
     wm transient $w .opts
     wm geometry $w +$DPOSX+$DPOSY
-    bind $w <Key-Return> { set TempAOpts ok ; set waitaopts 0 }
+    bind $w <Key-Return> { set TempAOpts ok }
 
     frame $w.fr -borderwidth 5 -bg $COLOUR(dialbg)
 
@@ -629,44 +698,55 @@ proc ShowOptionsArray {a} {
 	}
     }
     incr OptSubMany($a)
-    set i 0 ; set es ""
+    set i 0 ; set es "" ; set col 0
+    if { [set n [llength $OPTELS($a)]] < $OPTMAXHEIGHT } {
+	set row -1 ; set drow 0 ; set maxrow 1000
+    } else {
+	set row 0 ; set drow 1
+	if { [set z [expr int($n/$OPTMAXHEIGHT)]] != 1.0*$n/$OPTMAXHEIGHT } {
+	    incr z
+	}
+	if { [set maxrow [expr int($n/$z)]] != $n/$z } { incr maxrow }
+    }
     foreach ix $OPTELS($a) {
 	set es [ShowOption $a $a,$ix [set a]($ix) $OPTELTYPE($a) \
-		           $w.fr.f$i $es $lv]
+		           $w.fr.f$i $es $lv $row $col]
 	incr i
+	if { [incr row $drow] > $maxrow } {
+	    set row 0 ; incr col
+	}
     }
 
     frame $w.fr.bs
-    button $w.fr.bs.ok -text Ok -command { set TempAOpts ok ; set waitaopts 0 }
-    button $w.fr.bs.cnc -text $TXT(cancel) \
-	    -command { set TempAOpts cnc ; set waitaopts 0 }
+    button $w.fr.bs.ok -text Ok -command { set TempAOpts ok }
+    button $w.fr.bs.cnc -text $TXT(cancel) -command { set TempAOpts cnc }
 
     pack $w.fr.bs.ok $w.fr.bs.cnc -side left -pady 5
-    pack $w.fr.bs $w.fr -side top
+    if { $row == -1 } {
+	pack $w.fr.bs $w.fr -side top
+    } else {
+	grid $w.fr.bs -row [incr maxrow] -column 0 -columnspan [incr col] \
+		-pady 5
+	pack $w.fr -side top
+    }
 
-    set pw [grab current]
     update idletasks
+    set gs [grab current]
     grab $w
-    # RaiseWindow $w
+    # cannot use RaiseWindow
     while 1 {
-	tkwait variable waitaopts
+	tkwait variable TempAOpts
 
 	switch $TempAOpts {
-	    ""  { }
 	    cnc { 
-		destroy $w
-		if { "$pw" != "" } {
-		    grab [lindex $pw 0]
-		}
 		foreach ref [array names OptOld$lv] {
 		                 # saved values of array elements
 		    ChangeOption $ref [set OptOld[set lv]($ref)]
 		    unset OptOld[set lv]($ref)
 		}
-		update idletasks
-		return
-	        }
-	    ok  {
+		break
+	    }
+	    ok {
 		set ok 1
 		foreach e $es {
 		                  # these are entries for array elements
@@ -674,9 +754,8 @@ proc ShowOptionsArray {a} {
 		    set i [expr 1+[string first , $ref]]
 		    set ix [string range $ref $i end]
 		    switch $OPTELTYPE($a) {
-			nat -
-			float -
-			any {
+			nat -  float -  any -
+			any_empty {
 			    set val [[lindex $e 0] get]
 			    if { [WrongValue $OPTELTYPE($a) $val] } {
 				GMMessage "$TXT(wrgval) $TXT(opt$ref)"
@@ -686,17 +765,13 @@ proc ShowOptionsArray {a} {
 			}
 		    }
 		}
-		if { $ok } {
-		    destroy $w
-		    if { "$pw" != "" } {
-			grab [lindex $pw 0]
-		    }
-		    update idletasks
-		    return
-		}
+		if { $ok } { break }
 	    }
 	}
     }
+    DestroyRGrabs $w $gs
+    update idletasks
+    return
 }
 
 proc ChangeMenuOption {val w} {
@@ -737,15 +812,16 @@ proc WrongValue {type val} {
 
     switch $type {
 	nat {
-	    if { [catch "set neq [expr $val!=round($val)]"] || \
+	    if { [catch {set neq [expr $val!=round($val)]}] || \
 		    $neq || $val<0 } { return 1 }
 	}
 	float {
-	    if { [catch "set val [expr $val]"] } { return 1 }
+	    if { [catch {set val [expr $val]}] } { return 1 }
 	}
 	any {
-	    if { "$val" == "" } { return 1 }
+	    if { $val == "" } { return 1 }
 	}
+	any_empty { return 0 }
     }
     return 0
 }
@@ -769,7 +845,7 @@ proc GenOption {f v} {
 	}
 	perms {
 	    global $v
-	    if { [catch "set OptPerms(owner,fread,$v)"] } {
+	    if { [catch {set OptPerms(owner,fread,$v)}] } {
 		puts $f "set $v [set $v]"
 	    } else {
 		puts -nonewline $f "set $v 0"
@@ -791,12 +867,13 @@ proc GenOption {f v} {
     return
 }
 
-proc ChooseColour {v ref val bw} {
+proc ChooseColour {v val bw mw} {
     # create modal dialog for choosing a colour
-    #  $v is a global variable
-    #  $ref is a reference used to keep the initial value of the option
-    #  $val is a reference to the option storage to be set
-    #  $bw is window with button and label to configure
+    #  $v is a global variable for the option storage (it may be an array)
+    #  $val is a reference to the option storage to be set (it may be
+    #   the an array name and index)
+    #  $bw is window with button .b and label .bc to configure
+    #  $mw is toplevel window using this proc
     global $v TXT TempCol ChColour ColComp DPOSX DPOSY COLOUR
 
     $bw.b configure -state normal
@@ -804,9 +881,9 @@ proc ChooseColour {v ref val bw} {
     if { [winfo exists $w] } { Raise $w ; bell ; return }
 
     toplevel $w
-    wm protocol $w WM_DELETE_WINDOW { set TempCol cnc ; set waitcopts 0 }
-    wm title $w "GPS Manager: $TXT(options)"
-    wm transient $w .opts
+    wm protocol $w WM_DELETE_WINDOW { set TempCol cnc }
+    wm title $w "$TXT(options)/GPS Manager"
+    wm transient $w $mw
     set x [expr $DPOSX+100] ; set y [expr $DPOSY+100]
     wm geometry $w +$x+$y
 
@@ -832,16 +909,18 @@ proc ChooseColour {v ref val bw} {
 
     set self [frame $w.fr.fr1.sel]
     label $self.lab -text "$TXT(selection):" -anchor sw
-    entry $self.ent -textvariable ChColour -width 16
+    entry $self.ent -width 16
     TextBindings $self.ent
     bind $self.ent <Return> "ColSelChange $w ; break"
+    bind $self.ent <Any-Leave> "ColSelChange $w ; break"
+    $self.ent insert 0 $ChColour
     frame $self.f1 -relief sunken -bd 2
     canvas $self.f1.demo -bd 0 -width 100 -height 15 -bg $ChColour
 
     frame $w.fr.bs
-    button $w.fr.bs.ok -text Ok -command { set TempCol ok ; set waitcopts 0 }
+    button $w.fr.bs.ok -text Ok -command { set TempCol ok }
     button $w.fr.bs.cnc -text $TXT(cancel) \
-	    -command { set TempCol cnc ; set waitcopts 0 }
+	-command { set TempCol cnc }
 
     pack $self.lab $self.ent -side top -fill x -padx 4 -pady 2
     pack $self.f1 -expand yes -anchor nw -fill both -padx 6 -pady 10
@@ -850,35 +929,27 @@ proc ChooseColour {v ref val bw} {
     pack $w.fr.bs.ok $w.fr.bs.cnc -side left -pady 5
     pack $w.fr.fr1 $w.fr.bs $w.fr -side top
 
-    set pw [grab current]
     update idletasks
+    set gs [grab current]
     grab $w
     RaiseWindow $w
     while 1 {
-	tkwait variable waitcopts
+	tkwait variable TempCol
 
 	switch $TempCol {
-	    ""  { }
 	    cnc {
-		destroy $w
-		if { "$pw" != "" } {
-		    grab [lindex $pw 0]
-		}
-		update idletasks
-		return
+		break
 	    }
 	    ok {
 		set $val $ChColour
 		$bw.bc configure -background $ChColour
-		destroy $w
-		if { "$pw" != "" } {
-		    grab [lindex $pw 0]
-		}
-		update idletasks
-		return
+		break
 	    }
 	}
     }
+    DestroyRGrabs $w $gs
+    update idletasks
+    return
 }
 
 proc RGBChange {w args} {
@@ -888,6 +959,8 @@ proc RGBChange {w args} {
 
     set ChColour [DecToColour $ColComp(red) $ColComp(green) $ColComp(blue)]
     $w.fr.fr1.sel.f1.demo configure -bg $ChColour
+    $w.fr.fr1.sel.ent delete 0 end
+    $w.fr.fr1.sel.ent insert 0 $ChColour
     return
 }
 
@@ -897,7 +970,12 @@ proc ColSelChange {w} {
     global ChColour ColComp
 
     if { [set x [ColourToDec [$w.fr.fr1.sel.ent get]]] == -1 } {
-	bell ; return
+	$w.fr.fr1.sel.ent delete 0 end
+	$w.fr.fr1.sel.ent insert 0 $ChColour
+	$w.fr.fr1.sel.f1.demo configure -bg $ChColour
+	update idletasks
+	bell
+	return
     }
     set ChColour [eval DecToColour $x]
     $w.fr.fr1.sel.ent icursor end
@@ -907,57 +985,6 @@ proc ColSelChange {w} {
     return
 }
 
-proc ColourToDec {c} {
-    # convert name to RGB values
-    global RGBNamed SRCDIR WorkDir
-
-    if { [string first # $c] == 0 } {
-	if {[scan $c "#%c%c%c%c%c%c" h0 h1 h2 h3 h4 h5]!=6 } { return -1 }
-	set b2 0 ; set b1 0 ; set b0 0
-	for { set i 0 } { $i<6 } { incr i } {
-	    set v b[expr int($i/2)]
-	    set $v [expr 16*[set $v]+[HexCharToDec [set h$i]]]
-	}
-    } else {
-	if {! [array exists RGBNamed] } {
-	    set d [pwd] ; cd $WorkDir
-	    source [file join $SRCDIR rgb.tcl]
-	    cd $d
-	}
-	if { "[array names RGBNamed $c]" == "" } { return -1 }
-	scan $RGBNamed($c) "%d %d %d" b0 b1 b2
-    }
-    return "$b0 $b1 $b2"
-}
-
-proc HexCharToDec {x} {
-    # convert hexadecimal character to decimal value
-
-    if { $x < 65 } {
-	return [expr $x-48]
-    } elseif { $x < 97 } {
-	return [expr $x-55]
-    }
-    return [expr $x-87]
-}
-
-proc DecToColour {c2 c1 c0} {
-    # convert RGB in decimal-triplet to hexadecimal representation
-
-    set d [expr 65536*$c2+256*$c1+$c0]
-    for { set i 0 } { $i<6 } { incr i } {
-	set h$i [DecToHexChar [expr $d%16]]
-	set d [expr int($d/16)]
-    }
-    return [format "#%c%c%c%c%c%c" $h5 $h4 $h3 $h2 $h1 $h0]
-}
-
-proc DecToHexChar {d} {
-    # convert RGB as decimal integer to hexadecimal representation
-
-    if { $d < 10 } { return [expr $d+48] } else { return [expr $d+87] }
-}
-
 proc PermsToList {p} {
     # convert octal permission to list of lists of bits
     # first digit (out of 4) of $p assumed to be always zero
