@@ -1,7 +1,7 @@
 #
 #  gpsman --- GPS Manager: a manager for GPS receiver data
 #
-#  Copyright (c) 2001 Miguel Filgueiras (mig@ncc.up.pt) / Universidade do Porto
+#  Copyright (c) 200 Miguel Filgueiras (mig@ncc.up.pt) / Universidade do Porto
 #
 #    This program is free software; you can redistribute it and/or modify
 #      it under the terms of the GNU General Public License as published by
@@ -17,17 +17,16 @@
 #      along with this program.
 #
 #  File: search.tcl
-#  Last change:  19 December 2001
+#  Last change:  18 January 2004
 #
 
 proc Search {} {
     # create dialog for searching items
-    global TempSearch PositionFormat SDatum Datum SearchWidgets SearchPattern \
-	    SearchDistance SearchWPName SearchWPSymbol SearchRTWP \
-	    SearchDate SearchSpec SearchDomain SearchDomGR \
-	    WPPosn WPDatum DEFAULTSYMBOL DPOSX DPOSY COLOUR TXT MESS TYPES \
-	    ICONWIDTH ICONHEIGHT SYMBOLIMAGE NAMEWIDTH DSCALE AzimuthDegrees \
-	    YEAR0 MONTHNAMES MAXMENUITEMS INVTXT
+    global PositionFormat SDatum Datum SearchWidgets SearchDistance \
+	SearchWPName SearchWPSymbol SearchRTWP SearchDate SearchSpec \
+	SearchDomain DEFAULTSYMBOL DPOSX DPOSY COLOUR TXT MESS TYPES \
+	ICONWIDTH ICONHEIGHT SYMBOLIMAGE NAMEWIDTH YEAR0 MONTHNAMES \
+	MAXMENUITEMS
 
     # absolute paths for this window used elsewhere
     set w .gmsearch
@@ -35,14 +34,13 @@ proc Search {} {
 
     set SDatum $Datum
     set SearchWPSymbol $DEFAULTSYMBOL
-    set waitsearch 1
 
     toplevel $w
-    wm protocol $w WM_DELETE_WINDOW "set TempSearch cnc ; set waitsearch 0"
-    wm title $w "GPS Manager: $TXT(search)"
+    wm protocol $w WM_DELETE_WINDOW "destroy $w"
+    wm title $w "$TXT(search)/GPS Manager"
     wm transient $w .
     wm geometry $w +$DPOSX+$DPOSY
-    bind $w <Key-Return> "set TempSearch ok ; set waitsearch 0"
+    bind $w <Key-Return> "DoSearch $w"
 
     frame $w.fr -relief flat -borderwidth 5 -bg $COLOUR(dialbg)
     label $w.fr.tit -text $TXT(search)
@@ -106,7 +104,7 @@ proc Search {} {
 	    -selectcolor $COLOUR(check) -anchor w
     frame $w.fr.fWPTR.dist.wpp.p.p -relief sunken -borderwidth 1
     ShowPosnDatum $w.fr.fWPTR.dist.wpp.p.p $PositionFormat "" \
-	    SearchChangeDatum SDatum normal 1 nil
+	    SearchChangeDatum SDatum SDatum normal 1 nil
     frame $w.fr.fWPTR.dir -relief flat -borderwidth 0
     label $w.fr.fWPTR.dir.tit -text $TXT(azimuth):
     set SearchDistance(bearing) ""
@@ -220,14 +218,13 @@ proc Search {} {
     set SearchWidgets(WP) "$w.fr.fWP.b TR/$w.fr.fWPTR.its.tit"
     set SearchWidgets(RT) "$w.fr.fRT.b"
     set SearchWidgets(TR) "$w.fr.fTR.b WP/$w.fr.fWPTR.its.tit"
+    set SearchWidgets(LN) ""
     set SearchWidgets(GR) ""
 
     frame $w.fr.frbt -relief flat -borderwidth 0
     button $w.fr.frbt.ok -text $TXT(search) \
-	    -command "set TempSearch ok ; set waitsearch 0 ; \
-	              $w.fr.frbt.ok configure -state normal"
-    button $w.fr.frbt.cnc -text $TXT(cancel) \
-	    -command "set TempSearch cnc ; set waitsearch 0"
+	    -command "$w.fr.frbt.ok configure -state normal ; DoSearch $w"
+    button $w.fr.frbt.cnc -text $TXT(cancel) -command "destroy $w"
 
     pack $w.fr.dom.db.b
     pack $w.fr.dom.gr.b $w.fr.dom.gr.mb -side left -padx 1
@@ -264,113 +261,98 @@ proc Search {} {
     pack $w.fr
 
     update idletasks
-    grab $w
-    # RaiseWindow $w
-    while 1 {
-	tkwait variable waitsearch
+    # apparently there is no need for a grab here
+    #  but if there is must take care of previous grabs (proc DestroyRGrabs)
+    # cannot use RaiseWindow because of the menus
+    return
+}
 
-	switch $TempSearch {
-	    ""  { }
-	    cnc { 
-		destroy $w
-		update idletasks
-		return
-	    }
-	    ok {
-		set whs ""
-		foreach wh $TYPES {
-		    if { $SearchSpec($wh) } { lappend whs $wh }
-		}
-		if { "$whs" == "" } {
-		    GMMessage $MESS(mustchoose1type)
-		    continue
-		}
-		foreach s "name cmmt rmrk" {
-		    if { $SearchSpec($s) } {
-			set SearchPattern($s) [$w.fr.strs.f$s.e get]
-		    }
-		}
-		if { $SearchSpec(dist) } {
-		    switch $SearchDistance(how) {
-			fromWP {
-			    set ix [IndexNamed WP $SearchWPName]
-			    if { $ix != -1 } {
-				set SearchDistance(pos) $WPPosn($ix)
-				set Sdatum $WPDatum($ix)
-			    } else {
-				GMMessage $MESS(badWP)
-				continue
-			    }
-			}
-			fromPos {
-			    set z $w.fr.fWPTR.dist.wpp.p.p.frp
-			    set p [PosnGetCheck $z $SDatum GMMessage nil]
-			    if { "$p" != "nil" } {
-				set SearchDistance(pos) $p
-				set SearchDistance(pformt) \
-					$INVTXT([$z.pfmt cget -text])
-			    } else { continue }
-			}
-		    }
-		    if { "$SearchDistance(bearing)" != "" } {
-			if { ! [CheckNumber GMMessage \
-				$SearchDistance(open)] } { continue }
-			if { $SearchDistance(open)>359 || \
-				$SearchDistance(open)==0 } {
-			    GMMessage $MESS(badangle)
-			    continue
-			}
-			set SearchDistance(hangle) [expr \
-				$SearchDistance(open)/2.0]
-			set SearchDistance(azimuth) \
-				$AzimuthDegrees($SearchDistance(bearing))
-		    } else {
-			set SearchDistance(hangle) 180
-			set SearchDistance(azimuth) 0
-		    }
-		    switch $SearchDistance(range) {
-			within {
-			    if { ! [CheckFloat GMMessage \
-				    $SearchDistance(dist)] } { continue }
-			    set SearchDistance(low) 0
-			    set SearchDistance(up) \
-				    [expr $DSCALE*$SearchDistance(dist)]
-			}
-			between {
-			    if { ! [CheckFloat GMMessage \
-				    $SearchDistance(from)] || ! [CheckFloat \
-				    GMMessage $SearchDistance(to)]} { 
-				continue
-			    }
-			    set SearchDistance(low) \
-				    [expr $DSCALE*$SearchDistance(from)]
-			    set SearchDistance(up) \
-				    [expr $DSCALE*$SearchDistance(to)]
-			}
-		    }
-		}
-		if { $SearchSpec(RTWP) && "$SearchRTWP" == "" } {
+proc DoSearch {w} {
+    # begin search
+    global TYPES SearchSpec SearchPattern SearchDistance SDatum SearchWPName \
+	SearchRTWP WPDatum WPPosn AzimuthDegrees DSCALE MESS INVTXT
+
+    set whs ""
+    foreach wh $TYPES {
+	if { $SearchSpec($wh) } { lappend whs $wh }
+    }
+    if { $whs == "" } {
+	GMMessage $MESS(mustchoose1type)
+	return
+    }
+    foreach s "name cmmt rmrk" {
+	if { $SearchSpec($s) } {
+	    set SearchPattern($s) [$w.fr.strs.f$s.e get]
+	}
+    }
+    if { $SearchSpec(dist) } {
+	switch $SearchDistance(how) {
+	    fromWP {
+		set ix [IndexNamed WP $SearchWPName]
+		if { $ix != -1 } {
+		    set SearchDistance(pos) $WPPosn($ix)
+		    set Sdatum $WPDatum($ix)
+		} else {
 		    GMMessage $MESS(badWP)
-		    continue
-		}
-		if { [SearchFor $whs] } {
-		    destroy $w
 		    return
 		}
 	    }
+	    fromPos {
+		set z $w.fr.fWPTR.dist.wpp.p.p.frp
+		set p [PosnGetCheck $z $SDatum GMMessage nil]
+		if { $p == "nil" } { return }
+		set SearchDistance(pos) $p
+		set SearchDistance(pformt) $INVTXT([$z.pfmt cget -text])
+	    }
+	}
+	if { $SearchDistance(bearing) != "" } {
+	    if { ! [CheckNumber GMMessage $SearchDistance(open)] } { return }
+	    if { $SearchDistance(open) > 359 || $SearchDistance(open) == 0 } {
+		GMMessage $MESS(badangle)
+		return
+	    }
+	    set SearchDistance(hangle) [expr $SearchDistance(open)/2.0]
+	    set SearchDistance(azimuth) \
+		$AzimuthDegrees($SearchDistance(bearing))
+	} else {
+	    set SearchDistance(hangle) 180
+	    set SearchDistance(azimuth) 0
+	}
+	switch $SearchDistance(range) {
+	    within {
+		if { ! [CheckFloat GMMessage $SearchDistance(dist)] } {
+		    return
+		}
+		set SearchDistance(low) 0
+		set SearchDistance(up) [expr $DSCALE*$SearchDistance(dist)]
+	    }
+	    between {
+		if { ! [CheckFloat GMMessage $SearchDistance(from)] || \
+			 ! [CheckFloat GMMessage $SearchDistance(to)]} { 
+		    return
+		}
+		set SearchDistance(low) [expr $DSCALE*$SearchDistance(from)]
+		set SearchDistance(up) [expr $DSCALE*$SearchDistance(to)]
+	    }
 	}
     }
+    if { $SearchSpec(RTWP) && $SearchRTWP == "" } {
+	GMMessage $MESS(badWP)
+	return
+    }
+    if { [SearchFor $whs] } { destroy $w }
+    return
 }
 
 proc SearchDescription {} {
-    # return a text describing the search constraints which are described
+    # return a text with the search constraints which are described
     #  by global variables (see proc SearchForAny) and the state of the
     #  search window
     global SearchDomain SearchDomGR GRName SearchSpec SearchPattern \
 	    SearchDistance SearchWPName SDatum SearchWPSymbol SearchRTWP \
 	    SearchDate TXT
 
-    if { "$SearchDomain" == "GR" } {
+    if { $SearchDomain == "GR" } {
 	set ddomgr "" ; set p ""
 	foreach ix $SearchDomGR {
 	    lappend ddomgr "${p}$GRName($ix)"
@@ -397,7 +379,7 @@ proc SearchDescription {} {
 		set ddistfrom "$TXT(from) $pf $p ($SDatum)"
 	    }
 	}
-	if { "[set b $SearchDistance(bearing)]" != "" } {
+	if { [set b $SearchDistance(bearing)] != "" } {
 	    set ddistbear \
 		    " $TXT(azimuth) $b, $TXT(opening) $SearchDistance(open);\n"
 	} else { set ddistbear "" }
@@ -428,7 +410,7 @@ proc SearchDescription {} {
 	set dtrdt "${f}$TXT(date) $SearchDate(d) $SearchDate(m) $SearchDate(y)"
 	set f ";\n"
     }
-    if { "$f" != "" } { set f "\n" }
+    if { $f != "" } { set f "\n" }
     return "${ddom}\n${dstrs}${fstrs}${ddist}${dsymb}${drtwp}${dtrdt}.$f"
 }
 
@@ -448,16 +430,16 @@ proc SearchFor {whs} {
 	set ids [lindex $Storage($wh) 0]
 	global $ids
 
-	if { "$SearchDomain" == "GR" } {
+	if { $SearchDomain == "GR" } {
 	    set ixs [GRsElements $SearchDomGR 1 $wh]
 	} else {
 	    set ixs [array names $ids]
 	}
-	if { "[set ns [SearchForAny $ids $ixs $wh]]" != "" } {
+	if { [set ns [SearchForAny $ids $ixs $wh]] != "" } {
 	    lappend lp [list $wh $ns]
 	}
     }
-    if { "$lp" != "" } { return [SearchResults $lp] }
+    if { $lp != "" } { return [SearchResults $lp] }
     GMMessage $MESS(nosuchitems)
     return 0
 }
@@ -490,20 +472,21 @@ proc SearchForAny {ids ixs wh} {
     global SearchSpec SearchPattern SDatum SearchWPSymbol SearchRTWP \
 	    SearchDate WPPosn WPDatum RTWPoints TRTPoints TRDatum
 
-    if { "$ixs" == "" } { return "" }
+    if { $ixs == "" } { return "" }
     foreach s "name rmrk" a "$ids ${wh}Obs" {
 	if { $SearchSpec($s) } {
 	    set ixs [SearchFilter $a $ixs $SearchPattern($s)]
 	}
     }
-    if { "$ixs" == "" } { return "" }
+    if { $ixs == "" } { return "" }
     switch $wh {
 	WP {
 	    if { $SearchSpec(cmmt) } {
 		set ixs [SearchFilter WPCommt $ixs $SearchPattern(cmmt)]
 	    }
 	    if { $SearchSpec(symbol) } {
-		# this is safe only if symbol names are alpha-numeric
+		# this is safe only if symbol names have no meta-chars
+		#  used in "string match"
 		set ixs [SearchFilter WPSymbol $ixs $SearchWPSymbol]
 	    }
 	    if { $SearchSpec(dist) } {
@@ -525,7 +508,7 @@ proc SearchForAny {ids ixs wh} {
 		set nixs ""
 		foreach ix $ixs {
 		    foreach wpn $RTWPoints($ix) {
-			if { "$SearchRTWP" == "$wpn" } {
+			if { $SearchRTWP == $wpn } {
 			    lappend nixs $ix
 			    break
 			}
@@ -538,7 +521,7 @@ proc SearchForAny {ids ixs wh} {
 	    if { $SearchSpec(date) } {
 		set s 3
 		foreach a "d m y" {
-		    if { "[set $a $SearchDate($a)]" == "" } {
+		    if { [set $a $SearchDate($a)] == "" } {
 			set $a *
 			incr s -1
 		    }
@@ -579,7 +562,7 @@ proc SearchDistConstr {pos datum} {
     # assume SetDatumData $SDatum has been called
     global SearchDistance SDatum
 
-    if  { "$SDatum" != "$datum" } {
+    if  { $SDatum != $datum } {
 	set pos [ConvertDatum [lindex $pos 0] [lindex $pos 1] \
 		$datum $SDatum DDD]
     }
@@ -647,12 +630,10 @@ proc SearchToggleDomain {} {
     # if selection is cancelled search domain reverts to data-base
     global SearchDomain SearchDomGR GRName TXT
 
-    if { "$SearchDomain" == "Data" } { return }
+    if { $SearchDomain == "Data" } { return }
     set w .gmsearch
     $w.fr.dom.gr.mb.m delete 0 end
     set SearchDomGR [ChooseItems GR]
-    grab $w
-    # RaiseWindow $w
     switch [llength $SearchDomGR] {
 	0 {
 	    set SearchDomain Data
@@ -703,24 +684,8 @@ proc SearchToggle {wh} {
 proc SearchChangeDatum {datum args} {
     # change datum of search window
     #  $args is not used but is needed as this is called-back from a menu
-    global SDatum INVTXT MESS
 
-    set w .gmsearch.fr.fWPTR.dist.wpp.p.p
-    if { "$SDatum" == "$datum" } { return }
-    set op [PosnGetCheck $w.frp $SDatum Ignore nil]
-    set pformt $INVTXT([$w.frp.pfmt cget -text])
-    if { ("[set pt [PosType $pformt]]" == "grid" || "$pt" == "nzgrid") && \
-	    "[set gdatum [GridDatum $pformt]]" != "" && \
-	    "$datum" != "$gdatum" } {
-	GMMessage [format $MESS(cantchggriddatum) $gdatum]
-	return
-    }
-    if { "$op" != "nil" } {
-	set np [ConvertDatum [lindex $op 0] [lindex $op 1] \
-		$SDatum $datum $pformt]
-	RevertPos $w.frp $pformt $pt "$np"
-    }
-    set SDatum $datum
+    ChangeDatum $datum SDatum SDatum nil .gmsearch.fr.fWPTR.dist.wpp.p.p.frp
     return
 }
 
